Package: IntramiRExploreR
Title: Predicting Targets for Drosophila Intragenic miRNAs
Version: 1.35.0
Author: Surajit Bhattacharya and Daniel Cox
Maintainer: Surajit Bhattacharya <sbhattach2@childrensnational.org>
Description: Intra-miR-ExploreR, an integrative miRNA target prediction
    bioinformatics tool, identifies targets combining expression and biophysical
    interactions of a given microRNA (miR). Using the tool, we have identified
    targets for 92 intragenic miRs in D. melanogaster, using available microarray
    expression data, from Affymetrix 1 and Affymetrix2 microarray array platforms,
    providing a global perspective of intragenic miR targets in Drosophila.
    Predicted targets are grouped according to biological functions using the DAVID
    Gene Ontology tool and are ranked based on a biologically relevant scoring
    system, enabling the user to identify functionally relevant targets for a given
    miR.
Depends: R (>= 3.4)
Imports: igraph (>= 1.0.1), FGNet (>= 3.0.7), knitr (>= 1.12.3), stats,
        utils, grDevices, graphics
Suggests: gProfileR, topGO, org.Dm.eg.db, rmarkdown, testthat
VignetteBuilder: knitr
License: GPL-2
biocViews: Software, Microarray, GeneTarget, StatisticalMethod,
        GeneExpression, GenePrediction
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.2
URL: https://github.com/VilainLab/IntramiRExploreR
BugReports: https://github.com/VilainLab/IntramiRExploreR
git_url: https://git.bioconductor.org/packages/IntramiRExploreR
git_branch: devel
git_last_commit: 2400d90
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:18:59 UTC; biocbuild

# Generated by roxygen2: do not edit by hand

export(Gene_Visualisation)
export(GetGOS_ALL)
export(Visualisation)
export(extract_HostGene)
export(extract_intragenic_miR)
export(genes_Stat)
export(miRTargets_Stat)
import(FGNet)
import(grDevices)
import(graphics)
import(igraph)
import(knitr)
import(utils)
importFrom(stats,na.omit)

---
title: "IntramiRExploreR_Vignettes_ver05"
author: "Surajit Bhattacharyal and Daniel N. Cox"
date: "Friday, December 09, 2016"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{IntramiRExploreR}
  %\VignetteEngine{knitr::rmarkdown}
  \usepackage[utf8]{inputenc}
---

##Introduction

Micro RNAs (**miRNAs**) are a group of small non-coding RNAs (21-25 nucleotide long),which have been associated with post-transcriptional Gene Silencing, since its discovery in ***C.elegans*** as a regulator of larval  development (R. C. Lee, Feinbaum, & Ambros, 1993; Wightman, Ha, & Ruvkun, 1993). miRNAs play a major roles in various developmental and disease conditions, however one significant challenge in characterizing the mechanism via which miRNAs exert their post-transcriptional effect is the identification of biologically relevant target mRNAs, given that miRNAs exhibit a one-to-many relationship with their putative target mRNAs. Most microRNA Target prediction tools look at biophysical properties like seed sequence matching and Gibbs Free Energy, but that does not take into consideration the expression of the miRNA of the tissue of interest. 

This is an important parameter to take into account, as the expression of the miRNA, along with the physical properties discussed earlier, would determine effectively whether a particular miRNA plays a functional role in the process of interest. Although there have been tools available which predict targets for a given microRNA based on statistical correlation between miRNA expression and mRNA expression values. But this approach has 2 caveats:
a) The miRNA expression values both microarray and RNA-seq expression values are limited compared to those mRNAs.
b) Other than human and mouse, the number of miRNA expression data is quite limited for other model organisms like D.melanogaster, and predicting miRNA functionality across the whole genome is quite difficult

One method to bypass this impediment and use expression profiles to identify miRNA targets, in a model organism like Drosophila, is to focus on intragenic miRNAs, which are located within host protein coding genes. Intragenic miRNAs constitute approximately 60% of all miRNAs in ***Drosophila melanogaster*** (Fruit Flies), making these miRNAs an important component in post-transcriptional regulation of gene expression. Reports have confirmed that the expression of intragenic miRNAs is highly correlated with the expression of the host gene mRNA (Baskerville & Bartel 2005; Karali et al. 2007; Kim & Kim 2007). Based upon this correlation, it is possible to use the host gene expression values as a proxy for the expression of the intragenic miRNA (Tsang et al. 2007). Target prediction of intragenic miRNAs using the host gene expression has been successfully implemented in Humans, with the HOCTAR algorithm (Gennarino et al. 2008; Gennarino et al. 2011). Given that there are much larger available datasets for mRNA expression profiles, than miRNA expression profiles, by using the host gene as a proxy for the intragenic miRNA, one can significantly extend bioinformatic analyses and statistical power in predicting miRNA:mRNA target interactions, that are rooted not only in target prediction algorithms, but also in biologically relevant, and inversely correlated, patterns of expression between a miRNA and potential target mRNAs.

The IntramiRExploreR tool using 2 distinct correlation methods Distance and Pearson correlation finds targets for miRNA in Fruit flies using the availbale Affymetric microarray data available in the Gene Expression omnibus database. Other than the targets the tool also integrates Gene Ontology functionalities using FGNet(Bioconductor), Data from NCBI and visualisation tool using igraph.


###Installing the package

**IntramiEExploreR** is currently available from the github repository. Installation method would be as the following:

```{r eval=FALSE}
library("devtools")
devtools::install_github("sbhattacharya3/IntramiRExploreR")
```
```{r eval=TRUE}
library("IntramiRExploreR")
```
IntramiRExploreR has dependency on  R version (>= 3.1.2). To use the DAVID functionality for Gene Ontology functional classification (called from **GetGOS_ALL** function), user has to install the **RDAVIDWebService** package using the link below:
http://stackoverflow.com/questions/31480579/r-david-webservice-sudden-transport-error-301-error-moved-permanently.

###Target Prediction using expression data

For building up the intragenic miRNA target data base, we have used Affymetrix platform 1 & 2 microarray datasets for ***D.melanogaster***, from GEO database(Barrett et al., 2013). For the significance of the statistical analysis, experiments with greater than or equal to 5 assays were considered. The experiments were normalized using the Robust Multichip Average (RMA) (Bolstad, Irizarry, Astrand, & Speed, 2003) from the affy package (Gautier, Cope, Bolstad, & Irizarry, 2004)(Gautier et al., 2004) from the Bioconductor suite (Gentleman et al., 2004) in R. The statistical functions are then used to find the correlation between the host genes and each of the other genes in an experiment. The correlation methods used are Pearson Correlation (Lee Rodgers & Nicewander, 1988; Pearson, 1895) and distance correlation(Szekely & Rizzo, 2009). 

After the correlation analysis has been performed, a false discovery rate calculation, Benjamini Hochberg (BH) False Dicovery Rate (FDR) Calculation (Benjamini & Hochberg, 1995) is done on the p values obtained for each miRNA-mRNA pair for a particular experiment, using the p.adjust function in R. To identify statistically significant, anti-correlated mRNA targets (p<0) for a particular miRNA, all mRNAs with a q-value (FDR threshold) of less than 0.01 are selected across all experiments.  From these analyses, the top 25% most frequently occurring mRNAs are then compared with the targets predicted for a given miRNA in a variety of target databases (TargetScan, PITA, and Miranda).  A target gene which is found in the output list of both the statistical tests and also found in the target database can be called as a putative target for a given miRNA. To get the most important putative targets a scoring system has also been designed. The scoring system is a summation of  3 parameters:

1)  Probability of sequence conservation of both the targets and the miRNA, across the different species considered in TargetScan and Miranda databases.
2)  Number of complementary sites in a target for a given miRNA obtained from Pita Target Database.
3)  Probability of occurrence of the target:miRNA pair across the different experiments
 
These Statistically predicted targets for a given miRNA of interest can be obtained using **miRTargets_Stat** function, but can be visualized by the user using the **Visualisation** function.

These Statistically predicted targets for a given miRNA of interest can be obtained using **miRTargets_Stat** function.

```{r eval=TRUE}
miR="dme-miR-12"
a<-miRTargets_Stat(miR,method=c("Both"),Platform=c("Affy1"),Text=FALSE)
a[1:4,1:5]
```
The input to the function are single or multiple miRNAs, the Statitical method which predicts the target, and the platform. The method chosen here is "Both" which is an union of both the **Pearson** and the **Distance** correlation method. The platform is chosen as **Affy1** (Affymetrix platform1).  The  output from the function is targets that are statistically significant, the score associated to each target, the GEO accession IDS where the miRNA and the Targets are correlated and the function of the target genes from the flybase.

Similarly, **genes_Stat** is used to obtain statistically relevant miRNAs that target a gene of interest.

```{r eval=TRUE}
gene ="Ank2"
a<-genes_Stat(gene,geneIDType="GeneSymbol", method=c("Both"),Platform=c("Affy1"))
a[1:4,1:5]
```
**genes_Stat** has similar output format as **miRTargets_Stat**, the only difference is that it outs the miRNA function from flybase, instead of the genes.

**Visualisation** function has three output formats:
a)**text**: Output miRNA targets result obtained from **miRTargets_Stat**, in text format.
b)**Cytoscqape**: Output in the format of cytoscape input files.
c)**igraphs**: Output  miRNA:Target gene results in the form of network.
d)If no output format is chosen, a datframe containing the result returned to the user.

```{r eval=TRUE}
miR=c("dme-miR-12","dme-miR-283")
a<-Visualisation(miR,mRNA_type=c("GeneSymbol"),method=c("Both"),platform=c("Affy1"),
                visualisation=c("console"),thresh=10)
a[1:10,1:5]
```
The input to the function are single or multiple miRNAs, the Statitical method which predicts the target, and the platform. The method chosen here is "Both" which is an union of both the **Pearson** and the **Distance** correlation method. The platform is chosen as **Affy1** (Affymetrix platform1).  The  output from the function is targets that are statistically significant, the score associated to each target, the GEO accession IDS where the miRNA and the Targets are correlated and the function of the target genes from the flybase.

The output can be visualised using **igraph**.


Similarly, **Genes_Visualisation** is used to obtain statistically relevant miRNAs that target a gene of interest, as an output from **genes_Stat** function.

```{r eval=TRUE}
mRNA="Syb"
a<-Gene_Visualisation(mRNA,mRNA_type=c("GeneSymbol"),method=c("Pearson"),
            platform=c("Affy1"),visualisation= "console")
a[1:10,1:5]
```

The output can be visualised using **igraph**, similar to visualisation function.

####Gene Ontology

**GetGOS_ALL** function outputs functional network clusters, using FGNet. topGO and DAVID are the 2 available GO methods. 
```{r, eval=FALSE}
miR="dme-miR-12"
a<-Visualisation(miR,mRNA_type=c("GeneSymbol"),method=c("Both"),platform=c("Affy1"),thresh=100,
            visualisation="console")
genes<-a$Target_GeneSymbol
GetGOS_ALL(genes,GO=c("topGO"),term=c("GO_BP"),path="C://",filename="test")
```

####References

1. Baskerville, S., & Bartel, D. P. (2005). **Microarray profiling of microRNAs reveals frequent coexpression with neighboring miRNAs and host genes.** RNA (New York, N.Y.), 11(3), 241–7. http://doi.org/10.1261/rna.7240905
2. Gennarino, V. A., Sardiello, M., Avellino, R., Meola, N., Maselli, V., Anand, S., … Banfi, S. (2008). **MicroRNA target prediction by expression analysis of host genes.** Genome Research, 19(3), 481–490. http://doi.org/10.1101/gr.084129.108
3. Gennarino, V. A., Sardiello, M., Mutarelli, M., Dharmalingam, G., Maselli, V., Lago, G., & Banfi, S. (2011). **HOCTAR database: A unique resource for microRNA target prediction.** Gene, 480(1–2), 51–58. http://doi.org/10.1016/j.gene.2011.03.005
4. Karali, M., Peluso, I., Marigo, V., & Banfi, S. (2007). **Identification and characterization of microRNAs expressed in the mouse eye.** Investigative Ophthalmology & Visual Science, 48(2), 509–15. http://doi.org/10.1167/iovs.06-0866
5. Kim, Y.-K., & Kim, V. N. (2007). **Processing of intronic microRNAs.** The EMBO Journal, 26(3), 775–83. http://doi.org/10.1038/sj.emboj.7601512
6. Lee, R. C., Feinbaum, R. L., & Ambros, V. (1993). **The C. elegans heterochronic gene lin-4 encodes small RNAs with antisense complementarity to lin-14.** Cell, 75(5), 843–54. Retrieved from http://www.ncbi.nlm.nih.gov/pubmed/8252621
7. Tsang, J., Zhu, J., & van Oudenaarden, A. (2007). **MicroRNA-mediated feedback and feedforward loops are recurrent network motifs in mammals.** Molecular Cell, 26(5), 753–67. http://doi.org/10.1016/j.molcel.2007.05.018
8. Wightman, B., Ha, I., & Ruvkun, G. (1993). **Posttranscriptional regulation of the heterochronic gene lin-14 by lin-4 mediates temporal pattern formation in C. elegans.** Cell, 75(5), 855–62. Retrieved from http://www.ncbi.nlm.nih.gov/pubmed/8252622

#' Visualises the targetGene:miRNA network using Cytoscape and igraph .
#'
#' @param miRNA  character. miRNA Identifier.
#' @param mRNA_type  character. mRNA id type.
#'                   The choices are 'GeneSymbol','FBID' and 'CGID'.
#' @param method  character. Statistical Methods. Choices are
#'                'Pearson','Distance','Both'
#' @param platform  character. Affymetrix Platforms. Choices are
#'                'Affy1','Affy2'.
#' @param visualisation  character.Visualisation type.
#'                       Choices are 'igraph','Cytoscape','text' and 'console'.
#' @param path character. Path where data.frame is saved when visualisation
#'             is text. Default is tempdir().
#' @param thresh integar. Threshold depicting number of rows to show.
#' @param layout  character. Network choices. Choices are
#'                'kamadakawai','reingold.tilford','fruchterman.reingold' 
#'                and 'interactive'.
#' @return Depending upon the ouput choice network image or dataframe 
#'         containg miRNAs that target the query gene are ouput.
#' @examples
#' miRNA='dme-miR-12'
#' Visualisation(miRNA,mRNA_type=c('GeneSymbol'),method=c('Pearson'),
#' platform=c('Affy1'),visualisation=c('igraph'),layout=c('kamadakawai'),
#'            path=tempdir())
#' @import igraph utils grDevices graphics  
#' @importFrom stats na.omit
#' @export

Visualisation <- function(miRNA, mRNA_type = c("GeneSymbol", "FBID", "CGID"), 
    method = c("Pearson", "Distance", "Both"), platform = c("Affy1", "Affy2"), 
    thresh = 50, visualisation = c("igraph", "Cytoscape", "Text", "console"), 
    path = tempdir(), layout = c("kamadakawai", "reingold.tilford",
    "fruchterman.reingold", "interactive")) {
    ### Checks whether the length of query is greater than 1
    stopifnot(is.character(miRNA), length(miRNA) > 0, length(grep("dme-miR", 
        miRNA, ignore.case = TRUE)) > 0)
    stopifnot(is.character(mRNA_type), length(mRNA_type) > 0)
    stopifnot(is.character(method), length(method) > 0, method %in% c("Pearson", 
        "Distance", "Both", "BothIntersect"))
    stopifnot(is.character(platform), length(platform) > 0, platform %in% 
        c("Affy1", "Affy2"))
    stopifnot(is.character(visualisation), length(visualisation) > 0)
    ## miRNA length >1
    if (length(miRNA > 1)) {
        dat <- c()
        
        ## Extracts and sorts the data in descending order
        for (ii in seq_along(miRNA)) {
            stopifnot(length(extract_HostGene(miRNA[ii])) > 0)
            # print(miRNA[ii])
            a <- tryCatch({
                miRTargets_Stat(miRNA[ii], method, Platform = platform)
                
            }, error = function(e) {
                # print('mRNA record Absent')
                return(NA)
            })
            
            if (nrow(a) == 0) {
                stop("miRNA does not have any records")
            } else {
                commgenes <- as.character(a$Target_GeneSymbol)
                FBGN <- as.character(a$Targets_FBID)
                CGID <- as.character(a$Targets_CGID)
                sc <- as.numeric(a$Score)
                ord <- a[order(-sc), ]
                dat1 <- ord[1:thresh, ]
                dat <- rbind(dat, dat1)
            }
        }
        # If Visualisation is selected as Text, writes in a .csv
        # file Else If Visualisation is selected as Cytoscape, writes in a .csv
        # file in cytoscape format output Else If Visualisation is selected as
        # igraph, outputs in the format the layout is selected Else If
        # Visualisation is selected as console returns a data frame to the
        # console Else stops with error message
        if (identical(visualisation, "Text")) {
            ### If miRNA length >1 names concatenated with & else use the miR 
            ###name
            if (length(miRNA) > 1) {
                miRNAs <- paste(miRNA, collapse = "&")
            } else {
                miRNAs = miRNA
            }
            filename = paste("Putative_target_Score_for_", miRNAs, "_", 
                platform, "_and_", method, ".csv", sep = "")
            ### Check if the file name exists
            if (!(file.exists(file.path(path, filename)))) {
                write.csv(dat, file = file.path(path, filename))
            } else {
                stop("File Already Exists!!")
            }
            
        } else if (identical(visualisation, "Cytoscape")) {
            miR <- as.character(dat$miRNA)
            ## Checks if the mRNA_Type selected to print in the output table is
            ## GeneSymbol, Flybase Id (FBID) or CGID
            if (identical(mRNA_type, "GeneSymbol")) {
                gene <- as.character(dat$Target_GeneSymbol)
            } else if (identical(mRNA_type, "FBID")) {
                gene <- as.character(dat$Targets_FBID)
            } else if (identical(mRNA_type, "CGID")) {
                gene <- as.character(dat$Targets_CGID)
            } else {
                stop("mRNA_Type Invalid!!!")
            }
            Score <- as.numeric(dat$Score)
            ## Storing data in a dataframe
            datC <- data.frame(miRNA = miR, Interaction = rep("pp", 
                length(miR)), Gene = gene, Score)
            if (length(miRNA) > 1) {
                miRNAs <- paste(miRNA, collapse = "&")
            } else {
                miRNAs = miRNA
            }
            filename = paste("Cytoscape_output_for_", miRNAs, "_", platform, 
                "_and_", method, ".csv", sep = "")
            
            ## Checking if the file exists
            if (!(file.exists(file.path(path, filename)))) {
                write.csv(datC, file = file.path(path, filename))
            } else {
                stop("File Already Exists!!")
            }
        } else if (identical(visualisation, "igraph")) {
            datN <- c()
            ### Extracting the data and storing in the data.frame
            miR <- as.character(dat$miRNA)
            ## Checks if the mRNA_Type selected to print in the output table is
            ## GeneSymbol, Flybase Id (FBID) or CGID
            if (identical(mRNA_type, "GeneSymbol")) {
                gene <- as.character(dat$Target_GeneSymbol)
            } else if (identical(mRNA_type, "FBID")) {
                gene <- as.character(dat$Targets_FBID)
            } else if (identical(mRNA_type, "CGID")) {
                gene <- as.character(dat$Targets_CGID)
            } else {
                stop("mRNA_Type Invalid!!!")
            }
            Score <- as.numeric(dat$Score)
            datN <- data.frame(miRNA = miR, Gene = gene, Score)
            datN <- na.omit(datN)
            ### Creating the plot
            a <- graph.data.frame(datN, directed = FALSE)
            ### Creating the Edge weight
            E(a)$weight <- Score
            ### Selecting the layout to represent the network. The selected 
            ### network is printed out in the format of a .tiff file. If chosen
            ### layout iskamadakawai, prints as .tiff file If chosen layout is
            ### fruchterman.reingold, prints as .tiff file If chosen layout is
            ### reingold.tilford, prints as .tiff file If chosen layout is
            ### interactive, prints as a tkplot file Else Prints error message
            if (identical(layout, "kamadakawai")) {
                layout_graph <- layout.kamada.kawai(a)
                if (length(miRNA) > 1) {
                    miRNAs <- paste(miRNA, collapse = "&")
                } else {
                    miRNAs = miRNA
                }
                filename = paste("Graphical_output_for_", miRNAs, "_", 
                    platform, "_and_", method, ".tiff", sep = "")
                if (!(file.exists(file.path(path, filename)))) {
                    tiff(filename = file.path(path, filename), width = 1000, 
                    height = 1000, units = "px")
                    plot(a, layout = layout_graph, vertex.color = "red", 
                    edge.width = E(a)$weight)
                    dev.off()
                } else {
                    stop("File Already Exists!!")
                }
                
            } else if (identical(layout, "fruchterman.reingold")) {
                layout_graph <- layout.fruchterman.reingold(a)
                if (length(miRNA) > 1) {
                    miRNAs <- paste(miRNA, collapse = "&")
                } else {
                    miRNAs = miRNA
                }
                filename = paste("Graphical_output_for_", miRNAs, "_", 
                    platform, "_and_", method, ".tiff", sep = "")
                if (!(file.exists(file.path(path, filename)))) {
                    tiff(filename = file.path(path, filename), width = 1000, 
                    height = 1000, units = "px")
                    plot(a, layout = layout_graph, vertex.color = "red", 
                    edge.width = E(a)$weight)
                    dev.off()
                } else {
                    stop("File Already Exists!!")
                }
                
            } else if (identical(layout, "reingold.tilford")) {
                layout_graph <- layout.reingold.tilford(a)
                if (length(miRNA) > 1) {
                    miRNAs <- paste(miRNA, collapse = "&")
                } else {
                  miRNAs = miRNA
                }
                filename = paste("Graphical_output_for_", miRNAs, "_", 
                    platform, "_and_", method, ".tiff", sep = "")
                if (!(file.exists(file.path(path, filename)))) {
                    tiff(filename = file.path(path, filename), width = 1000, 
                    height = 1000, units = "px")
                    plot(a, layout = layout_graph, vertex.color = "red", 
                    edge.width = E(a)$weight)
                    dev.off()
                } else {
                    stop("File Already Exists!!")
                }
            } else if (identical(layout, "interactive")) {
                tkplot(a, vertex.color = "red", edge.width = E(a)$weight)
            } else {
                print("Invalid Layout!!!")
            }
        } else if (identical(visualisation, "console")) {
            
            return(dat)
        } else {
            stop("Visualisation Invalid")
        }
        
    } else {
        ## miRNA length ==1
        stopifnot(length(extract_HostGene(miRNA)) > 0)
        # dat <- c() Extracts and sorts the data in descending order
        a <- tryCatch({
            miRTargets_Stat(miRNA, method, Platform = platform)
            
        }, error = function(e) {
            # print('mRNA record Absent')
            return(NA)
        })
        if (nrow(a) == 0) {
            stop("miRNA does not have any records")
        } else {
            commgenes <- as.character
            (a$Target_GeneSymbol)
            FBGN <- as.character(a$Targets_FBID)
            CGID <- as.character(a$Targets_CGID)
            sc <- as.numeric(a$Score)
            ord <- a[order(-sc), ]
            dat1 <- ord[1:thresh, ]
            dat <- dat1
        }
        ### If Visualisation is selected as Text, writes in a .csv file Else If
        ### Visualisation is selected as Cytoscape, writes in a .csv file in
        ### cytoscape format output Else If Visualisation is selected as igraph,
        ### outputs in the format the layout is selected Else If Visualisation 
        ### is selected as console returns a data frame to the console Else stops
        ### with error message
        if (identical(visualisation, "Text")) {
            
            miRNAs = miRNA
            
            filename = paste("Putative_target_Score_for_", miRNAs, "_", 
                platform, "_and_", method, ".csv", sep = "")
            ## Checks whether the filename exists; prints if it does not previously
            ## exist
            if (!(file.exists(file.path(path, filename)))) {
                write.csv(dat, file = file.path(path, filename))
            } else {
                stop("File Already Exists!!")
            }
            
        } else if (identical(visualisation, "Cytoscape")) {
            ## Extracting individual data and storing it in the database.
            miR <- as.character(dat$miRNA)
            ## Checks if the mRNA_Type selected to print in the output table is
            ## GeneSymbol, Flybase Id (FBID) or CGID
            if (identical(mRNA_type, "GeneSymbol")) {
                gene <- as.character(dat$Target_GeneSymbol)
            } else if (identical(mRNA_type, "FBID")) {
                gene <- as.character(dat$Targets_FBID)
            } else if (identical(mRNA_type, "CGID")) {
                gene <- as.character(dat$Targets_CGID)
            } else {
                stop("mRNA_Type Invalid!!!")
            }
            Score <- as.numeric(dat$Score)
            ## Storing data in a dataframe
            datC <- data.frame(miRNA = miR, Interaction = rep("pp", 
                    length(miR)), Gene = gene, Score)
            miRNAs = miRNA
            ## Checks whether the filename exists; prints if it does not
            ##  previously exist
            filename = paste("Cytoscape_output_for_", miRNAs, "_", platform, 
                "_and_", method, ".csv", sep = "")
            if (!(file.exists(file.path(path, filename)))) {
                write.csv(datC, file = file.path(path, filename))
            } else {
                stop("File Already Exists!!")
            }
        } else if (identical(visualisation, "igraph")) {
            datN <- c()
            ## Extracting individual data and storing it in the database.
            miR <- as.character(dat$miRNA)
            ## Checks if the mRNA_Type selected to print in the output table is
            ## GeneSymbol, Flybase Id (FBID) or CGID
            if (identical(mRNA_type, "GeneSymbol")) {
                gene <- as.character(dat$Target_GeneSymbol)
            } else if (identical(mRNA_type, "FBID")) {
                gene <- as.character(dat$Targets_FBID)
            } else if (identical(mRNA_type, "CGID")) {
                gene <- as.character(dat$Targets_CGID)
            } else {
                stop("mRNA_Type Invalid!!!")
            }
            Score <- as.numeric(dat$Score)
            ## Storing data in the dataframe
            datN <- data.frame(miRNA = miR, Gene = gene, Score)
            datN <- na.omit(datN)
            ## Creating the network
            a <- graph.data.frame(datN, directed = FALSE)
            ### Score assigned as edge weight
            E(a)$weight <- Score
            ### Selecting the layout to represent the network. The selected 
            ### network is printed out in the format of a .tiff file. If chosen
            ### layout iskamadakawai, prints as .tiff file If chosen layout is
            ### fruchterman.reingold, prints as .tiff file If chosen layout is
            ### reingold.tilford, prints as .tiff file If chosen layout is
            ### interactive, prints as a tkplot file Else Prints error message
            if (identical(layout, "kamadakawai")) {
                layout_graph <- layout.kamada.kawai(a)
                miRNAs = miRNA
                
                filename = paste("Graphical_output_for_", miRNAs, "_", 
                    platform, "_and_", method, ".tiff", sep = "")
                if (!(file.exists(file.path(path, filename)))) {
                    tiff(filename = file.path(path, filename), width = 1000, 
                    height = 1000, units = "px")
                    plot(a, layout = layout_graph, vertex.color = "red", 
                    edge.width = E(a)$weight)
                    dev.off()
                } else {
                    stop("File Already Exists!!")
                }
                
            } else if (identical(layout, "fruchterman.reingold")) {
                layout_graph <- layout.fruchterman.reingold(a)
                miRNAs = miRNA
                if (!(file.exists(file.path(path, filename)))) {
                    tiff(filename = file.path(path, filename), width = 1000, 
                    height = 1000, units = "px")
                    plot(a, layout = layout_graph, vertex.color = "red", 
                    edge.width = E(a)$weight)
                    dev.off()
                } else {
                    stop("File Already Exists!!")
                }
                
            } else if (identical(layout, "reingold.tilford")) {
                layout_graph <- layout.reingold.tilford(a)
                miRNAs = miRNA
                if (!(file.exists(file.path(path, filename)))) {
                    tiff(filename = file.path(path, filename), width = 1000, 
                    height = 1000, units = "px")
                    plot(a, layout = layout_graph, vertex.color = "red", 
                    edge.width = E(a)$weight)
                    dev.off()
                } else {
                    stop("File Already Exists!!")
                }
            } else if (identical(layout, "interactive")) {
                tkplot(a, vertex.color = "red", edge.width = E(a)$weight)
            } else {
                stop("Invalid Layout!!!")
            }
        } else if (identical(visualisation, "console")) {
            ## Return data to the console
            return(dat)
        } else {
            stop("Visualisation Invalid")
        }
        
    }
}

###Retrieves the Targets for a given query miRNA
###using the algorithm.
#Input: miRNA, Statistical method, Platform.
#Output:Dataframe containing miRNA and Target genes (in Gene Symbol,
#       FBGN and CG IDs), score, experments where the correlation happens.

library(IntramiRExploreR)
test_Visualisation<-function(){
###Checking a positive case, with single miRNA
miRNA="dme-miR-12"
result<-Visualisation(miRNA,mRNA_type=c("GeneSymbol"),method=c("Pearson"),
				platform=c("Affy1"))
expect_true(is.data.frame(result))
###Checking a positive case, with multiple miRNA
miRNA=c("dme-miR-12","dme-miR-283")
result<-Visualisation(miRNA,mRNA_type=c("GeneSymbol"),method=c("Pearson"),
				platform=c("Affy1"))
expect_true(is.data.frame(result))
###Checking a negative case with a non-intragenic miRNA
miRNA="dme-miR-120"
expect_that(Visualisation(miRNA,mRNA_type=c("GeneSymbol"),
                method=c("Pearson"),platform=c("Affy1")),throws_error())
###Checking a negative case with an invalid platform
miRNA="dme-miR-12"
expect_that(Visualisation(miRNA,mRNA_type=c("GeneSymbol"),
                method=c("Pearson"),platform=c("Affy12")),throws_error())
###Checking a negative case with an invalid method
miRNA="dme-miR-12"
expect_that(Visualisation(miRNA,mRNA_type=c("GeneSymbol"),
                method=c("Pearsons"),platform=c("Affy12")),throws_error())
###Checking a negative case with an invalid method
miRNA="dme-miR-12"
expect_that(Visualisation(miRNA,mRNA_type=c("ABC"),
                method=c("Pearsons"),platform=c("Affy12")),throws_error())

}
###Retrieves the miRNAS  for a given query Target mRNA
###using the algorithm.
#Input: mRNA, Statistical method, Platform.
#Output:Dataframe containing miRNA and Target genes (in Gene Symbol,
#       FBGN and CG IDs), score, experments where the correlation happens.

test_Genes_Visualisation<-function(){
###Checking a positive case; single mRNA
mRNA="Syb"
result<-Gene_Visualisation(mRNA,mRNA_type=c("GeneSymbol"),method=c("Pearson"),
				  platform=c("Affy1"))
expect_true(is.data.frame(result))
expect_equal(ncol(result),9)
###Checking a positive case;multiple mRNAs
mRNA=c("Syb","Ank2")
result<-Gene_Visualisation(mRNA,mRNA_type=c("GeneSymbol"),method=c("Pearson"),
				  platform=c("Affy1"))
expect_true(is.data.frame(result))
expect_equal(ncol(result),9)
###Checking a negative case with a mRNA with no record
mRNA=c("PkaC1")
expect_that(Gene_Visualisation(mRNA,mRNA_type=c("GeneSymbol"),method=c("Pearson"),
				  platform=c("Affy1")),throws_error())

###Checking a negative case; with invalid method
mRNA=c("Syb")
expect_that(Gene_Visualisation(mRNA,mRNA_type=c("GeneSymbol"),method=c("Pearsson"),
				  platform=c("Affy1")),throws_error())
###Checking a negative case; with invalid platform
mRNA=c("Syb")
expect_that(Gene_Visualisation(mRNA,mRNA_type=c("GeneSymbol"),method=c("Pearson"),
				  platform=c("Affy3")),throws_error())
###Checking a negative case; with invalid mRNA_type 
mRNA=c("Syb")
expect_that(Gene_Visualisation(mRNA,mRNA_type=c("QABCCC"),method=c("Pearson"),
				  platform=c("Affy1")),throws_error())
}

.onAttach <- function(libname, pkgname) {
    msg <- sprintf(
        "Package '%s' is deprecated and will be removed from Bioconductor
         version %s", pkgname, "3.14")
    .Deprecated(msg=paste(strwrap(msg, exdent=2), collapse="\n"))
}

#' Extract Intragenic miRNA for a given Host gene.
#'
#' @param gene  character. Gene Symbol.
#' @return miRf, a character string or vector containing
#'         Intragenic miRNA for the Host Gene.
#' @examples
#' gene="Gmap"
#' extract_intragenic_miR(gene)
#' @import utils 
#' @export

extract_intragenic_miR <- function(gene) {
    ###Checking the validity of the input
    stopifnot(is.character(gene), length(gene) > 0)
    ###Calling the database to get miRNAs in the 
    ###host genes
    data("miRNA_summary_DB", envir = environment())
    miRNA_summary_DB <- miRNA_summary_DB
    ###Extracting data
    gen <- as.character(miRNA_summary_DB$Gene)
    miR <- as.character(miRNA_summary_DB$miRNA)
    ###Preprocessing Search query
    g <- paste("^", gene, "$", sep = "")
    genf <- c()
    miRf <- c()
    if (length(g) > 1) {###If length of input >1
        ###Initiating the for loop
        for (ki in seq_along(g)) {
            ###Searching for the miRNAs for a 
            ##given host  gene
            d <- grep(g[ki], gen, ignore.case = TRUE)
            miRt <- c()
            if (length(d) > 1) { ###If multiple miRNAs in Host gene
                for (j in seq_along(d)) {
                    n <- d[j]
                    miRt <- c(miRt, miR[n])
                }
                ###Storing data
                miRf <- c(miRf, unique(as.character(miRt)))
                genf <- c(genf, rep(as.character(gene[ki]), 
                        length(unique(miRt))))
            } else { ###If single miRNAs in Host gene
                miRf <- c(miRf, as.character(miR[d]))
                genf <- c(genf, rep(as.character(gene[ki]), 1))
            }
        }
    } else if (length(g) == 1) {###If Length of query ==1 
        ###Searching for the miRNAs for a 
        ##given host  gene
        d <- grep(g, gen, ignore.case = TRUE)
        if (length(d) > 1) {###If multiple miRNAs in Host gene
            miRf <- c()
            ##Extracting data
            for (li in seq_along(d)) {
                n <- d[li]
                miRf <- c(miRf, unique(as.character(miR[n])))
            }
            
            miRf <- unique(miRf)
        } else {###If single miRNAs in Host gene
            miRf <- as.character(unique(miR[d]))
        }
    } else {### If Host gene does not have an intragenic miRNA
        stop("Host gene does not have a intragenic miRNA")
    }
    ###returns miRNA
    return(as.character(miRf))
}
#' Extract Host Gene for a given Intragenic miRNA.
#'
#' @param miRNA  A String containing the miRNA name.
#' @return genf, a character string or vector containing
#'         Host gene for the Intragenic miRNA.
#' @examples
#' miRNA="dme-miR-12"
#' extract_HostGene(miRNA)
#' @import utils 
#' @export
extract_HostGene <- function(miRNA) {
    ###Checking the validity of the input
    stopifnot(is.character(miRNA), length(miRNA) > 0, length(grep("dme-miR", 
        miRNA, ignore.case = TRUE)) > 0)
    ##Calls the database
    miRNA_summary_DB <- c()
    data("miRNA_summary_DB", envir = environment())
    miRNA_summary_DB <- miRNA_summary_DB
    gen <- as.character(miRNA_summary_DB$Gene)
    miR <- as.character(miRNA_summary_DB$miRNA)
    ###Preprocessing Search query
    m <- paste("^", miRNA, "$", sep = "")
    genf <- c()
    miRf <- c()
    if (length(m) > 1) {###If Length of query ==1 
        ###Searching for the host gene for a 
        ##given miRNA
        for (ki in seq_along(m)) {
            d <- grep(m[ki], miR, ignore.case = TRUE)
            gent <- c()
            if (length(d) > 1) {##if multiple genes
                for (j in 1:length(d)) {
                    n <- d[j]
                    gent <- c(gent, gen[n])
                }
                genf <- c(genf, unique(as.character(gent)))
                miRf <- c(miRf, rep(as.character(miR[ki]), 
                        length(unique(gent))))
            } else {
                genf <- c(genf, unique(as.character(gent[d])))
                miRf <- c(miRf, rep(as.character(miR[ki]), 1))
            }
        }
    } else if (length(m) == 1) {##if single genes
        d <- grep(m, miR, ignore.case = TRUE)
        if (length(d) > 1) {
            genef <- c()
            for (li in seq_along(d)) {
                n <- d[li]
                genef <- c(genef, unique(as.character(gen[n])))
            }
            genef <- unique(genef)
        } else {
            genef <- as.character(unique(gen[d]))
            genf <- genef
        }
    } else {
        stop("miRNA not intragenic")
    }
    ###returns Host Gene
    return(as.character(genf))
}

###Retrieves the Host Gene for a given miRNA.
#Input: miRNA
#Output:HostGene

library(IntramiRExploreR)
test_extract_HostGene<-function(){
###Checking a positive case
result<-extract_HostGene("dme-miR-12")
expect_equal(length(result), 1)
###Checking a negative case
result1<-extract_HostGene("dme-miR-120")
expect_equal(length(result1), 0)
}
###Retrieves the Intragenic miRNA for a given host gene.
#Input: Host Gene
#Output:Intragenic miRNA
test_extract_intragenic_miR<-function(){
###Checking a positive case
result<-extract_intragenic_miR("Gmap")
expect_equal(length(result), 1)
###Checking a negative case
result1<-extract_intragenic_miR("Syb")
expect_equal(length(result1), 0)
}

###Retrieves the Targets for a given query miRNA
###using the algorithm.
#Input: miRNA, Statistical method, Platform.
#Output:Dataframe containing miRNA and Target genes (in Gene Symbol,
#       FBGN and CG IDs), score, experments where the correlation happens.

library(IntramiRExploreR)
test_GetGOsALL<-function(){
###Checking a negative case, with less number of genes than threshold
miR="dme-miR-12"
a<-Visualisation(miR,mRNA_type=c("GeneSymbol"),method=c("Both"),
                platform=c("Affy1"),thresh=20)
genes<-a$Target_GeneSymbol
expect_that(GetGOS_ALL(genes,GO=c("topGO"),ontology=c("GO_BP"),path=tempdir() ,
            filename="test"),throws_error())
###Checking a negative case; with 2 ontology as input for topGO
miR="dme-miR-12"
a<-Visualisation(miR,mRNA_type=c("GeneSymbol"),method=c("Both"),
                platform=c("Affy1"),thresh=100)
genes<-a$Target_GeneSymbol
expect_that(GetGOS_ALL(genes,GO=c("topGO"),ontology=c("GO_BP","GO_MF"),path=tempdir() ,
            filename="test"),throws_error())
###Checking a negative case; with no ontology as input for topGO
miR="dme-miR-12"
a<-Visualisation(miR,mRNA_type=c("GeneSymbol"),method=c("Both"),
                platform=c("Affy1"),thresh=100)
genes<-a$Target_GeneSymbol
expect_that(GetGOS_ALL(genes,GO=c("topGO"),path=tempdir() ,
            filename="test"),throws_error())
###Checking a negative case; with no term as input for DAVID
miR="dme-miR-12"
a<-Visualisation(miR,mRNA_type=c("GeneSymbol"),method=c("Both"),
                platform=c("Affy1"),thresh=100)
genes<-a$Target_GeneSymbol
expect_that(GetGOS_ALL(genes,GO=c("DAVID"),path=tempdir() ,
            filename="test"),throws_error())
###Checking a negative case; with 2 terms as input for DAVID
miR="dme-miR-12"
a<-Visualisation(miR,mRNA_type=c("GeneSymbol"),method=c("Both"),
                platform=c("Affy1"),thresh=100)
genes<-a$Target_GeneSymbol
expect_that(GetGOS_ALL(genes,GO=c("DAVID"), term=c("GOTERM_BP_ALL", 
            "GOTERM_MF_ALL"), path=tempdir() ,filename="test"),
  			throws_error())
###Checking a negative case; with 2 incorrect GO
miR="dme-miR-12"
a<-Visualisation(miR,mRNA_type=c("GeneSymbol"),method=c("Both"),
                platform=c("Affy1"),thresh=100)
genes<-a$Target_GeneSymbol
expect_that(GetGOS_ALL(genes,GO=c("ABC"), term=c("GOTERM_BP_ALL", 
            "GOTERM_MF_ALL"), path=tempdir() ,filename="test"),
  			throws_error())
}

#' IntramiRExploreR:Prediction of targets for Intragenic 
#' miRNA in Drosophila.
#'
#' Prediction of targets for Drosophila Intragenic microRNAs
#' and Integrated approach using Gene Ontology and Networking tools.
#'
#' @import knitr
#' @examples
#'\dontrun{
#' gene='Gmap'
#' extract_intragenic_miR(gene)
#' }
#' @docType package
#' @name IntramiRExploreR
NULL
# > [1] '_PACKAGE' 

#' Gene ontology for Target Genes.
#' 
#' @param gene List  A String or vector containing the Gene names.
#' @param GO   A String depicting the chosen GO tool. Choice is "topGO"
#' @param term  A String depicting the chosen term. Choices are
#'               "GOTERM_BP_ALL","GOTERM_MF_ALL", "GOTERM_CC_ALL".
#' @param geneIdType Type of gene Id given as input. Default "ALIAS"
#' @param filename Name of the file to store Gene Ontology.
#' @param ontology Ontology selection for topGO. Choices are
#'                 "GO_BP","GO_MF","GO_CC".
#' @param path  String. The path where the data is stored if TEXT=TRUE.
#' @return Depending upon the ouput choice data is stored in the path 
#'         specified. Default option prints output to the console.
#' @examples
#' \dontrun{
#' miR="dme-miR-12"
#' a<-Visualisation(miR,mRNA_type=c("GeneSymbol"),method=c("Both"),
#'    platform=c("Affy1"),thresh=100)
#' genes<-a$Target_GeneSymbol
#' GetGOS_ALL(genes,GO=c("topGO"),term=c("GO_BP"),path=tempdir(),
#'      filename="test")
#'  }
#' @import FGNet
#' @export
GetGOS_ALL <- function(gene, GO = c("topGO"), term = c("GOTERM_BP_ALL", 
    "GOTERM_MF_ALL", "GOTERM_CC_ALL"), geneIdType = "ALIAS", path = tempdir(), 
    ontology = c("GO_BP", "GO_MF", "GO_CC"), filename) {
    #Checking the gene length, term and ontology is entered correctly
    stopifnot(is.character(gene), length(gene) > 20)
    stopifnot(is.character(term), length(term) == 1)
    stopifnot(is.character(ontology), length(ontology) == 1)
    stopifnot(is.character(GO), length(GO) == 1, GO %in% c("topGO"))
    ### If GO chosen as DAVID do DAVID functional clustering Else do topGO
    ### functional Clustering
	###Old code as RDAVIDWebService is not working we use only topGO
    'if (identical(GO, "DAVID")) {
        ### Checking whether the email is correct
        stopifnot(is.character(email), length(email) > 0)
        ### If RDAVIDWebService is not installed, prompts you to install it.
        if (!requireNamespace("RDAVIDWebService", quietly = TRUE)) {
            stop("Please install RDAVIDWebService")
        } else {
            requireNamespace("RDAVIDWebService", quietly = TRUE)
        }
        ### Gene List input to David, preprocessing.
        geneList <- gene
        geneList1 <- gsub("FBGN", "FBgn", as.character(geneList))
        geneList1 <- gsub("FBGN", "fbgn", as.character(geneList))
        ### URL for DAVID
        url = "https://david.ncifcrf.gov/webservice/services/DAVIDWebService.DAVIDWebServiceHttpSoap12Endpoint/"
        ### Connecting to DAVID
        david <- RDAVIDWebService::DAVIDWebService(email, url)
        RDAVIDWebService::connect(david)
        ### Obtaining result from DAVID
        result <- RDAVIDWebService::addList(david, geneList1, idType = "FLYBASE_GENE_ID", 
            listName = "Targets", listType = "Gene")
        term <- as.character(term)
        RDAVIDWebService::setAnnotationCategories(david, term)
        termCluster <- RDAVIDWebService::getClusterReport(david, type = "Term")
        RDAVIDWebService::getClusterReportFile(david, type = "Term", fileName = paste(path, 
            "//", term, "_ClusterReport.tab", sep = ""))
        genetemp <- gProfileR::gconvert(unique(as.character(geneList1)), 
            organism = "dmelanogaster", target = "ENSG")
        fbgn <- as.character(genetemp$alias)
        gene <- as.character(genetemp$name)
        names(gene) <- as.character(fbgn)
        ### Result Input to FBGN
        filename <- paste(term, "_ClusterReport.tab", sep = "")
        fearesults <- FGNet::format_david(file.path(path, filename), jobName = "DavidAnalysis", 
            geneLabels = gene)
        FGNet::FGNet_report(fearesults, plotKeggPw = FALSE)
    } else {
        stopifnot(is.character(geneIdType), length(geneIdType) > 0)
        ### Preprocessing input to topgo
        filename <- paste(filename, "_topGO", sep = "")
        gene <- gene
        term <- as.character(term)
        geneIdType = geneIdType
        filename <- paste(term, "TOPGOAnalysis", sep = "")
        ### Input data to topGO via FBGN
        feaResults_topGO <- FGNet::fea_topGO(gene, geneIdType, geneLabels = NULL, 
            organisms = "Dm", annotations = ontology, genesUniverse = NULL, 
            refPackage = NULL, geneID2GO = NULL, nodeSize = 5, pValThr = 0.01, 
            testStat = NULL, jobName = file.path(path, filename))
        FGNet_report(feaResults_topGO, plotKeggPw = FALSE)
    }'
	
	if(identical(GO, "topGO")){
	    stopifnot(is.character(geneIdType), length(geneIdType) > 0)
        ### Preprocessing input to topgo
        filename <- paste(filename, "_topGO", sep = "")
        gene <- gene
        term <- as.character(term)
        geneIdType = geneIdType
        filename <- paste(term, "TOPGOAnalysis", sep = "")
        ### Input data to topGO via FBGN
        feaResults_topGO <- FGNet::fea_topGO(gene, geneIdType, geneLabels = NULL, 
            organisms = "Dm", annotations = ontology, genesUniverse = NULL, 
            refPackage = NULL, geneID2GO = NULL, nodeSize = 5, pValThr = 0.01, 
            testStat = NULL, jobName = file.path(path, filename))
        FGNet_report(feaResults_topGO, plotKeggPw = FALSE)
	}else{stop("GO method invalid!!!!")}
	
    
}

#' Targets for the microRNA analyzed from Affy1 plaform using Pearson.
#'
#' A precomputed dataset containing the targets, scores and other 
#' attributes of 83 intragenic microRNAs using Pearson Correlation 
#' for plaform Affymetrix 1.
#' @format A data frame with 41845 rows and 8 variables:
#' \describe{
#'   \item{miRNA}{miRNA name, miRNA symbol}
#'   \item{GeneSymbol}{Gene name, in Gene Symbol}
#'   \item{FBGN}{Gene name, in FlybaseID}
#'   \item{CGID}{Gene name, in CGID}
#'   \item{Score}{Computed Score, in float}
#'   \item{GeneFunction}{Gene Functions, from Flybase}
#'   \item{experiments}{Experiments, from ArrayExpress}
#'   \item{TargetDatabases}{Target Database Name, from TargetDatabases}
#' }
"Affy1_Pearson_Final"
# > [1] 'Affy1_Pearson_Final'
#' Targets for the microRNA analyzed from Affy1 plaform using Distance.
#'
#' A precomputed dataset containing the targets, scores and other 
#' attributes of 83 intragenic microRNAs using Distance Correlation 
#' for plaform Affymetrix 1.
#' @format A data frame with 53399 rows and 8 variables:
#' \describe{
#'   \item{miRNA}{miRNA name, miRNA symbol}
#'   \item{GeneSymbol}{Gene name, in Gene Symbol}
#'   \item{FBGN}{Gene name, in FlybaseID}
#'   \item{CGID}{Gene name, in CGID}
#'   \item{Score}{Computed Score, in float}
#'   \item{GeneFunction}{Gene Functions, from Flybase}
#'   \item{experiments}{Experiments, from ArrayExpress}
#'   \item{TargetDatabases}{Target Database Name, from TargetDatabases}
#' }
"Affy1_Distance_Final"
# > [1] 'Affy1_Distance_Final'
#' Targets for the microRNA analyzed from Affy2 plaform using Pearson.
#'
#' A precomputed dataset containing the targets, scores and other 
#' attributes of 83 intragenic microRNAs using Pearson Correlation 
#' for plaform Affymetrix 1.
#' @format A data frame with 52913 rows and 8 variables:
#' \describe{
#'   \item{miRNA}{miRNA name, miRNA symbol}
#'   \item{GeneSymbol}{Gene name, in Gene Symbol}
#'   \item{FBGN}{Gene name, in FlybaseID}
#'   \item{CGID}{Gene name, in CGID}
#'   \item{Score}{Computed Score, in float}
#'   \item{GeneFunction}{Gene Functions, from Flybase}
#'   \item{experiments}{Experiments, from ArrayExpress}
#'   \item{TargetDatabases}{Target Database Name, from TargetDatabases}
#' }
"Affy2_Pearson_Final"
# > [1] 'Affy2_Pearson_Final'
#' Targets for the microRNA analyzed from Affy2 plaform using Distance.
#'
#' A precomputed dataset containing the targets, scores and other 
#' attributes of 83 intragenic microRNAs using Distance Correlation 
#' for plaform Affymetrix 1.
#' @format A data frame with 73374 rows and 8 variables:
#' \describe{
#'   \item{miRNA}{miRNA name, miRNA symbol}
#'   \item{GeneSymbol}{Gene name, in Gene Symbol}
#'   \item{FBGN}{Gene name, in FlybaseID}
#'   \item{CGID}{Gene name, in CGID}
#'   \item{Score}{Computed Score, in float}
#'   \item{GeneFunction}{Gene Functions, from Flybase}
#'   \item{experiments}{Experiments, from ArrayExpress}
#'   \item{TargetDatabases}{Target Database Name, from TargetDatabases}
#' }
"Affy2_Distance_Final"
# > [1] 'Affy2_Distance_Final'
#' Contains the summary for the intragenic miRNA.
#'
#' A dataset containing the summary for the intragenic miRNA.
#' @format A data frame with 257 rows and 6 variables:
#' \describe{
#'   \item{miRNA}{miRNA name, miRNA symbol}
#'   \item{Intragenic}{Responsee, in boolean}
#'   \item{Intergenic}{Responsee, in boolean}
#'   \item{Gene}{miRNA name, miRNA symbol}
#'   \item{Type.of.HostGene.mRNA.lncRNA.}{Type of Hostgene}
#'   \item{Notes}{Comments about the miRNA}
#' }
"miRNA_summary_DB"
# > [1] 'miRNA_summary_DB'
#' Contains the miRNA function information from Flybase database.
#'
#' A dataset containing the function for the intragenic miRNA.
#' @format A data frame with 66 rows and 4 variables:
#' \describe{
#'   \item{miRNA}{miRNA name, miRNA symbol}
#'   \item{FBGN}{target gene name, gene symbol}
#'   \item{miRNAFunction}{miRNA function, from Flybase}
#' }
#' @source \url{http://flybase.org/}
"miRNA_ID_to_Function"
# > [1] 'miRNA_ID_to_Function' 

#' Visualises the targetGene:miRNA network using Cytoscape and igraph .
#'
#' @param mRNA  character. gene Identifier.
#' @param mRNA_type  character. mRNA id type.
#'                   The choices are 'GeneSymbol','FBID' and 'CGID'.
#' @param method  character. Statistical Methods. Choices are
#'                'Pearson','Distance','Both'
#' @param platform  character. Affymetrix Platforms. Choices are
#'                'Affy1','Affy2'.
#' @param visualisation  character.Visualisation type.
#'                       Choices are 'igraph','Cytoscape','text'and "console"
#' @param path character. Path where data.frame is saved when visualisation
#'             is text. Default is tempdir().
#' @param layout  character. Network choices. Choices are
#'              'kamadakawai','reingold.tilford','fruchterman.reingold' 
#'                and 'interactive'.
#' @return Depending upon the ouput choice network image or dataframe 
#'         containg miRNAs that target the query gene are ouput.
#' @examples
#' mRNA='Syb'
#' Gene_Visualisation(mRNA,mRNA_type=c('GeneSymbol'),method=c('Pearson'),
#'                   platform=c('Affy1'), visualisation = "console")
#' @import igraph utils grDevices graphics 
#' @importFrom stats na.omit 
#' @export
Gene_Visualisation <- function(mRNA, mRNA_type = c("GeneSymbol", "FBGN", 
    "CGID"), method = c("Pearson", "Distance", "Both"), platform = c("Affy1", 
    "Affy2"), visualisation = c("igraph", "Cytoscape", "text", "console"), 
    path = tempdir(), layout = c("kamadakawai", "reingold.tilford", "fruchterman.reingold", 
        "interactive")) {
    ### Checking if input is valid
    stopifnot(is.character(mRNA), length(mRNA) > 0)
    stopifnot(is.character(mRNA_type), length(mRNA_type) > 0)
    stopifnot(is.character(method), length(method) > 0, method %in% c("Pearson", 
        "Distance", "Both"))
    stopifnot(is.character(platform), length(platform) > 0, platform %in% 
        c("Affy1", "Affy2"))
    stopifnot(is.character(visualisation), length(visualisation) > 0)
    ### If length >1
    if (length(mRNA) > 1) {
        
        dat <- c()
        ## Extracts and sorts the data in descending order
        for (ii in 1:length(mRNA)) {
            a <- tryCatch({
                genes_Stat(mRNA[ii], mRNA_type, method, Platform = platform)
                # return(expr)
            }, error = function(e) {
                # stop('mRNA record Absent')
                return(NA)
            })
            if (nrow(a) == 0) {
                stop("mRNA does not have any records")
            } else {
                commgenes <- as.character(a$Gene)
                FBGN <- as.character(a$Gene_FBGN)
                CGID <- as.character(a$Genes_CGID)
                sc <- as.numeric(a$Score)
                ord <- a[order(-sc), ]
                dat1 <- ord
                dat <- rbind(dat, dat1)
            }
            
            
            
        }
        ## If Visualisation is selected as Text If Visualisation is selected as
        ## Text, writes in a .csv file Else If Visualisation is selected as
        ## Cytoscape, writes in a .csv file in cytoscape format output Else If
        ## Visualisation is selected as igraph, outputs in the format the layout
        ## is selected Else If Visualisation is selected as console, outputs the
        ## dataframe to the console. Else prints error.
        if (identical(visualisation, "Text")) {
            ### If miRNA length >1 names concatenated with & else use the miR name
            if (length(mRNA) > 1) {
                mRNAs <- paste(mRNA, collapse = "&")
            } else {
                mRNAs = mRNA
            }
            filename = paste("Putative_miRNAs_for_", mRNAs, "_", platform, 
                "_and_", method, ".csv", sep = "")
            ### Check if the file name exists and if not print data in .csv format
            if (!(file.exists(file.path(path, filename)))) {
                write.csv(dat, file = file.path(path, filename))
            } else {
                stop("File Already Exists!!")
            }
            
        } else if (identical(visualisation, "Cytoscape")) {
            ## Extracting individual data and storing it in the database.
            miR <- as.character(dat$miRNA)
            ## Checks if the mRNA_Type selected to print in the output table is
            ## GeneSymbol, Flybase Id (FBID) or CGID
            if (identical(mRNA_type, "GeneSymbol")) {
                gene <- as.character(dat$Gene)
            } else if (identical(mRNA_type, "FBGN")) {
                gene <- as.character(dat$Gene_FBGN)
            } else if (identical(mRNA_type, "CGID")) {
                gene <- as.character(dat$Genes_CGID)
            } else {
                stop("mRNA_Type Invalid!!!")
            }
            Score <- as.numeric(dat$Score)
            ## Storing data in a dataframe
            datC <- data.frame(Gene = gene, Interaction = rep("pp", length(miR)), 
                miRNA = miR, Score)
            if (length(mRNA) > 1) {
                mRNAs <- paste(mRNA, collapse = "&")
            } else {
                mRNAs = mRNA
            }
            filename = paste("Cytoscape_output_for_", mRNAs, "_", platform, 
                "_and_", method, ".csv", sep = "")
            ## Checking if the file exists and writing the data in .csv format
            if (!(file.exists(file.path(path, filename)))) {
                write.csv(datC, file = file.path(path, filename))
            } else {
                stop("File Already Exists!!")
            }
        } else if (identical(visualisation, "igraph")) {
            ### Extracting the data and storing in the data.frame
            miR <- as.character(dat$miRNA)
            ## Checks if the mRNA_Type selected to print in the output table is
            ## GeneSymbol, Flybase Id (FBID) or CGID
            if (identical(mRNA_type, "GeneSymbol")) {
                gene <- as.character(dat$Gene)
            } else if (identical(mRNA_type, "FBGN")) {
                gene <- as.character(dat$Gene_FBGN)
            } else if (identical(mRNA_type, "CGID")) {
                gene <- as.character(dat$Genes_CGID)
            } else {
                stop("mRNA_Type Invalid!!!")
            }
            Score <- as.numeric(dat$Score)
            datN <- data.frame(Gene = gene, miRNA = miR, Score)
            ### Creating the plot
            a <- graph.data.frame(datN, directed = FALSE)
            ### Creating the Edge weight
            E(a)$weight <- Score
            ### Selecting the layout to represent the network. The selected network
            ### is printed out in the format of a .tiff file.  If chosen layout is
            ### kamadakawai, prints as .tiff file If chosen layout is
            ### fruchterman.reingold, prints as .tiff file If chosen layout is
            ### reingold.tilford, prints as .tiff file If chosen layout is
            ### interactive, prints as a tkplot file Else Prints error message
            if (identical(layout, "kamadakawai")) {
                layout_graph <- layout.kamada.kawai(a)
                if (length(mRNA) > 1) {
                  mRNAs <- paste(mRNA, collapse = "&")
                } else {
                  mRNAs = mRNA
                }
                filename = paste("Graphical_output_for_", mRNAs, "_", platform, 
                  "_and_", method, ".tiff", sep = "")
                if (!(file.exists(file.path(path, filename)))) {
                  tiff(filename = file.path(path, filename), width = 1000, 
                    height = 1000, units = "px")
                  plot(a, layout = layout_graph, vertex.color = "red", 
                    edge.width = E(a)$weight)
                  dev.off()
                } else {
                  stop("File Already Exists!!")
                }
                
            } else if (identical(layout, "fruchterman.reingold")) {
                layout_graph <- layout.fruchterman.reingold(a)
                if (length(mRNA) > 1) {
                  mRNAs <- paste(mRNA, collapse = "&")
                } else {
                  mRNAs = mRNA
                }
                filename = paste("Graphical_output_for_", mRNAs, "_", platform, 
                  "_and_", method, ".tiff", sep = "")
                if (!(file.exists(file.path(path, filename)))) {
                  tiff(filename = file.path(path, filename), width = 1000, 
                    height = 1000, units = "px")
                  plot(a, layout = layout_graph, vertex.color = "red", 
                    edge.width = E(a)$weight)
                  dev.off()
                } else {
                  stop("File Already Exists!!")
                }
                
            } else if (identical(layout, "reingold.tilford")) {
                layout_graph <- layout.reingold.tilford(a)
                if (length(mRNA) > 1) {
                  mRNAs <- paste(mRNA, collapse = "&")
                } else {
                  mRNAs = mRNA
                }
                filename = paste("Graphical_output_for_", mRNAs, "_", platform, 
                  "_and_", method, ".tiff", sep = "")
                if (!(file.exists(file.path(path, filename)))) {
                  tiff(filename = file.path(path, filename), width = 1000, 
                    height = 1000, units = "px")
                  plot(a, layout = layout_graph, vertex.color = "red", 
                    edge.width = E(a)$weight)
                  dev.off()
                } else {
                  stop("File Already Exists!!")
                }
            } else if (identical(layout, "interactive")) {
                tkplot(a, vertex.color = "red", edge.width = E(a)$weight)
            } else {
                stop("Invalid Layout!!!")
            }
        } else if (identical(visualisation, "console")) {
            ## Return data to the console
            return(dat)
        } else {
            stop("Visualisation method absent")
        }
    } else {
        ## Extracts and sorts the data in descending order
        dat <- c()
        a <- tryCatch({
            genes_Stat(mRNA, mRNA_type, method, Platform = platform)
            # return(expr)
        }, error = function(e) {
            # stop('mRNA record Absent')
            return(NA)
        })
        if (nrow(a) == 0) {
            stop("mRNA does not have any records")
        } else {
            commgenes <- as.character(a$Gene)
            FBGN <- as.character(a$Gene_FBGN)
            CGID <- as.character(a$Genes_CGID)
            sc <- as.numeric(a$Score)
            ord <- a[order(-sc), ]
            dat1 <- ord
            dat <- dat1
            # print(dat[1, ])
        }
        ## If Visualisation is selected as Text If Visualisation is selected as
        ## Text, writes in a .csv file Else If Visualisation is selected as
        ## Cytoscape, writes in a .csv file in cytoscape format output Else If
        ## Visualisation is selected as igraph, outputs in the format the layout
        ## is selected Else If Visualisation is selected as console, outputs the
        ## dataframe to the console. Else prints error.
        if (identical(visualisation, "Text")) {
            
            mRNAs = mRNA
            
            filename = paste("Putative_mRNAs_for_", mRNAs, "_", platform, 
                "_and_", method, ".csv", sep = "")
            ### Check if the file name exists and if not print data in .csv format
            if (!(file.exists(file.path(path, filename)))) {
                write.csv(dat, file = file.path(path, filename))
            } else {
                stop("File Already Exists!!")
            }
            
        } else if (identical(visualisation, "Cytoscape")) {
            ## Extracting individual data and storing it in the database.
            miR <- as.character(dat$miRNA)
            ## Checks if the mRNA_Type selected to print in the output table is
            ## GeneSymbol, Flybase Id (FBID) or CGID
            if (identical(mRNA_type, "GeneSymbol")) {
                gene <- as.character(dat$Gene)
            } else if (identical(mRNA_type, "FBGN")) {
                gene <- as.character(dat$Gene_FBGN)
            } else if (identical(mRNA_type, "CGID")) {
                gene <- as.character(dat$Genes_CGID)
            } else {
                stop("mRNA_Type Invalid!!!")
            }
            Score <- as.numeric(dat$Score)
            datC <- data.frame(Gene = gene, Interaction = rep("pp", length(miR)), 
                miRNA = miR, Score)
            mRNAs = mRNA
            filename = paste("Cytoscape_output_for_", mRNAs, "_", platform, 
                "_and_", method, ".csv", sep = "")
            ## Checking if the file exists and writing the data in .csv format
            if (!(file.exists(file.path(path, filename)))) {
                write.csv(datC, file = file.path(path, filename))
            } else {
                stop("File Already Exists!!")
            }
        } else if (identical(visualisation, "igraph")) {
            ### Extracting the data and storing in the data.frame
            miR <- as.character(dat$miRNA)
            ## Checks if the mRNA_Type selected to print in the output table is
            ## GeneSymbol, Flybase Id (FBID) or CGID
            if (identical(mRNA_type, "GeneSymbol")) {
                gene <- as.character(dat$Gene)
            } else if (identical(mRNA_type, "FBGN")) {
                gene <- as.character(dat$Gene_FBGN)
            } else if (identical(mRNA_type, "CGID")) {
                gene <- as.character(dat$Genes_CGID)
            } else {
                stop("mRNA_Type Invalid!!!")
            }
            Score <- as.numeric(dat$Score)
            datN <- data.frame(Gene = gene, miRNA = miR, Score)
            ### Creating the plot
            a <- graph.data.frame(datN, directed = FALSE)
            ### Creating the Edge weight
            E(a)$weight <- Score
            ### Selecting the layout to represent the network. The selected network
            ### is printed out in the format of a .tiff file.  If chosen layout is
            ### kamadakawai, prints as .tiff file If chosenfruchterman.reingold,
            ### prints as .tiff file If chosen layout isreingold.tilford, prints as
            ### .tiff file If chosen layout isinteractive, prints as a tkplot file.
            ### Else Prints error message
            if (identical(layout, "kamadakawai")) {
                layout_graph <- layout.kamada.kawai(a)
                mRNAs = mRNA
                
                filename = paste("Graphical_output_for_", mRNAs, "_", platform, 
                  "_and_", method, ".tiff", sep = "")
                if (!(file.exists(file.path(path, filename)))) {
                  tiff(filename = file.path(path, filename), width = 1000, 
                    height = 1000, units = "px")
                  plot(a, layout = layout_graph, vertex.color = "red", 
                    edge.width = E(a)$weight)
                  dev.off()
                } else {
                  stop("File Already Exists!!")
                }
            } else if (identical(layout, "fruchterman.reingold")) {
                layout_graph <- layout.fruchterman.reingold(a)
                mRNAs = mRNA
                
                filename = paste("Graphical_output_for_", mRNAs, "_", platform, 
                  "_and_", method, ".tiff", sep = "")
                if (!(file.exists(file.path(path, filename)))) {
                  tiff(filename = file.path(path, filename), width = 1000, 
                    height = 1000, units = "px")
                  plot(a, layout = layout_graph, vertex.color = "red", 
                    edge.width = E(a)$weight)
                  dev.off()
                } else {
                  stop("File Already Exists!!")
                }
            } else if (identical(layout, "reingold.tilford")) {
                layout_graph <- layout.reingold.tilford(a)
                mRNAs = mRNA
                
                filename = paste("Graphical_output_for_", mRNAs, "_", platform, 
                  "_and_", method, ".tiff", sep = "")
                if (!(file.exists(file.path(path, filename)))) {
                  tiff(filename = file.path(path, filename), width = 1000, 
                    height = 1000, units = "px")
                  plot(a, layout = layout_graph, vertex.color = "red", 
                    edge.width = E(a)$weight)
                  dev.off()
                } else {
                  stop("File Already Exists!!")
                }
            } else if (identical(layout, "interactive")) {
                tkplot(a, vertex.color = "red", edge.width = E(a)$weight)
            } else {
                stop("Invalid Layout!!!")
            }
        } else if (identical(visualisation, "console")) {
            ## Return data to the console print(dat)
            return(dat)
        } else {
            stop("Visualisation method absent")
        }
    }
    # return(dat)
}

#' Extracting miRNAs that target a query gene.
#'
#' @param gene  character. gene Identifier.
#' @param geneIDType  character. GeneIDtype choices are 'GeneSymbol', 
#'                    'FBGN', 'CGID'                     
#' @param method  character. Choices are 'Pearson','Distance','Both' and
#'                 'BothIntersected'
#' @param Platform  character. Choices are
#'                'Affy1','Affy2'.
#' @param Text  logical . To choose between storing the data as text file.
#'              Default is FALSE.
#' @param outpath  character. The path where the data is stored if TEXT=TRUE.
#'                 Default is 
#' @return Outputs the miRNA information, Target Prediction Score, miRNA 
#'         miRNA function and Target Database that predicts the interaction in
#'         a dataframe.
#'         Depending upon the ouput choice data is stored in the
#'         path specified. Default option prints output to the console. 
#' @examples
#' gene="Syb"
#' genes_Stat(gene,geneIDType="GeneSymbol",method=c("Pearson"),
#'            Platform=c("Affy1"),Text=FALSE)
#' @import utils grDevices graphics 
#' @importFrom stats na.omit
#' @export

genes_Stat <- function(gene, geneIDType = c("GeneSymbol", "FBGN", "CGID"), 
    method = c("Pearson", "Distance", "Both", "BothIntersect"), Platform = c("Affy1", 
        "Affy2"), Text = FALSE, outpath = tempdir()) {
    ## Initialising and loading the databases
    Affy2_Distance_Final <- c()
    Affy1_Distance_Final <- c()
    Affy2_Pearson_Final <- c()
    Affy1_Pearson_Final <- c()
    data("Affy1_Pearson_Final", envir = environment())
    Affy1_Pearson_Final <- Affy1_Pearson_Final
    data("Affy1_Distance_Final", envir = environment())
    Affy1_Distance_Final <- Affy1_Distance_Final
    data("Affy2_Pearson_Final", envir = environment())
    Affy2_Pearson_Final <- Affy2_Pearson_Final
    data("Affy2_Distance_Final", envir = environment())
    Affy2_Distance_Final <- Affy2_Distance_Final
    data("miRNA_ID_to_Function", envir = environment())
    miRNA_ID_to_Function <- miRNA_ID_to_Function
    ## Checking for the input variables
    stopifnot(is.character(gene), length(gene) > 0)
    stopifnot(is.character(geneIDType), length(geneIDType) > 0)
    stopifnot(is.character(method), length(method) > 0, method %in% c("Pearson", 
        "Distance", "Both", "BothIntersect"))
    stopifnot(is.character(Platform), length(Platform) > 0, Platform %in% 
        c("Affy1", "Affy2"))
    ## Checks the method, the platform and geneIDType and extracts the data
    ## for each individual query gene.  First Checks whether the method is
    ## Pearson and platform is Affy1 Else Checks If the method is is Pearson
    ## and platform is Affy2 Else Checks If the method is is Distance and
    ## platform is Affy1 Else Checks If the method is is Distance and
    ## platform is Affy2 Else Checks If the method is is Both and platform
    ## is Affy1 Else Checks If the method is is Both and platform is Affy2
    ## Else Checks If the method is is BothIntersect and platform is Affy2
    ## Else Checks If the method is is BothIntersect and platform is Affy2
    ## Else prints the error message that Method/platform is invalid
    if (identical(method, "Pearson") & identical(Platform, "Affy1")) {
        ## Checks if the chosen geneIDType is GeneSymbol, FBGN or CGID else
        ## prints error message
        if (identical(geneIDType, "GeneSymbol")) {
            ### Extracts data when geneIDType is gene symbol and Platform is AFFY1
            dat <- Affy1_Pearson_Final[which(tolower(Affy1_Pearson_Final$GeneSymbol) %in% 
                tolower(gene)), ]
            if (nrow(dat) == 0) {
                stop("Records of the gene does not exist")
            } else {
                finaldat1 <- data.frame(dat[, 2], dat[, 1], dat[, 3:5], 
                  dat[, 7:8])
                miR <- finaldat1[, 2]
                mfunct <- c()
                # Extracts the miRNA function
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                    ignore.case = TRUE)
                    if (length(dd) == 1) {
                        mfunct <- c(mfunct,
                        as.character 
                        (miRNA_ID_to_Function$miRNAFunction[dd]))
                  } else {
                    mfunct <- c(mfunct, "NA")
                  }
                }
                ### Storing extracted data in a dataframe
                finaldat1 <- cbind(finaldat1, mfunct, method = rep("Pearson", 
                  nrow(finaldat1)), row.names = NULL)
                names(finaldat1) <- c("Gene", "miRNA", "Gene_FBID", "Genes_CGID", 
                  "Score", "Experiments", "TargetDatabase", "miRNAFunction", 
                  "Method")
            }
            
        } else if (identical(geneIDType, "FBGN")) {
            ### Extracts data when geneIDType is Flybase Gene ID and Platform is
            ### AFFY1
            dat <- Affy1_Pearson_Final[which(tolower(Affy1_Pearson_Final$FBGN) %in% 
                tolower(gene)), ]
            if (nrow(dat) == 0) {
                stop("Records of the gene does not exist")
            } else {
                finaldat1 <- data.frame(dat[, 3], dat[, 1], dat[, 2], dat[, 
                    4:5], dat[, 7:8])
                miR <- finaldat1[, 2]
                # Extracts the miRNA function
                mfunct <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                    ignore.case = TRUE)
                  if (length(dd) == 1) {
                    mfunct <- c(mfunct, 
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                  } else {
                    mfunct <- c(mfunct, "NA")
                  }
                }
                ## Storing the extracted data in a data frame
                finaldat1 <- cbind(finaldat1, mfunct, method = rep("Pearson", 
                    nrow(finaldat1)), row.names = NULL)
                names(finaldat1) <- c("FlybaseID", "miRNA", "GeneSymbol", 
                    "Genes_CGID", "Score", "Experiments", "TargetDatabase", 
                    "miRNAFunction", "Method")
            }
            
        } else if (identical(geneIDType, "CGID")) {
            ### Extracts data when geneIDType is Flybase Gene ID and Platform is
            ### AFFY1
            dat <- Affy1_Pearson_Final[which(tolower(Affy1_Pearson_Final$CGID)
                %in% tolower(gene)), ]
            if (nrow(dat) == 0) {
                stop("Records of the gene does not exist")
            } else {
                finaldat1 <- data.frame(dat[, 4], dat[, 1], dat[, 2:3], 
                dat[, 5], dat[, 7:8])
                miR <- finaldat1[, 2]
                ## Extracting miRNAfunction
                mfunct <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                    ignore.case = TRUE)
                  if (length(dd) == 1) {
                    mfunct <- c(mfunct, as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                  } else {
                    mfunct <- c(mfunct, "NA")
                  }
                }
                ## Storing the extracted data in a data frame
                finaldat1 <- cbind(finaldat1, mfunct, method = rep("Pearson", 
                    nrow(finaldat1)), row.names = NULL)
                names(finaldat1) <- c("Gene_CGID", "miRNA", "GeneSymbol", 
                    "Genes_FBID", "Score", "Experiments", "TargetDatabase", 
                    "miRNAFunction", "Method")
            }
            
        } else {
            stop("GeneIdtype Invalid")
        }
        ## If text is selected file written to outpath
        if (identical(Text, TRUE)) {
            if (length(gene) > 1) {
                Genes <- paste(gene, collapse = "&")
            } else {
                Genes = gene
            }
            ### Checks whether the file exists; write it in the path specified if
            ### file does not exist.
            filename = paste("miRNAs_for_Genes_", Genes, "_", Platform, 
                "_", method, ".csv", sep = "")
            if (!(file.exists(file.path(outpath, filename)))) {
                write.csv(finaldat1, file = file.path(outpath, filename))
            } else {
                stop("File Already Exists!!")
            }
            
            
        } else {
            return(finaldat1)
        }
    } else if (identical(method, "Pearson") & identical(Platform, "Affy2")) {
        ## Checks if the chosen geneIDType is GeneSymbol, FBGN or CGID else
        ## prints error message
        if (identical(geneIDType, "GeneSymbol")) {
            dat <- Affy2_Pearson_Final[which(tolower(Affy2_Pearson_Final$GeneSymbol) %in% 
                tolower(gene)), ]
            if (nrow(dat) == 0) {
                stop("Records of the gene does not exist")
            } else {
                finaldat1 <- data.frame(dat[, 2], dat[, 1], dat[, 3:5], 
                dat[, 7:8])
                miR <- finaldat1[, 2]
                ### Extracts miRNA function
                mfunct <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                    ignore.case = TRUE)
                  if (length(dd) == 1) {
                    mfunct <- c(mfunct, 
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                } else {
                    mfunct <- c(mfunct, "NA")
                  }
                }
                ## Storing the data in data.frame
                finaldat1 <- cbind(finaldat1, mfunct, method = rep("Pearson", 
                    nrow(finaldat1)), row.names = NULL)
                names(finaldat1) <- c("Gene", "miRNA", "Gene_FBID", "Genes_CGID", 
                    "Score", "Experiments", "TargetDatabase", "miRNAFunction", 
                    "Method")
            }
            
        } else if (identical(geneIDType, "FBGN")) {
            ### Extracts data when geneIDType is FBGN and Platform is AFFY2
            dat <- Affy2_Pearson_Final[which(tolower(Affy2_Pearson_Final$FBGN) %in% 
                tolower(gene)), ]
            if (nrow(dat) == 0) {
                stop("Records of the gene does not exist")
            } else {
                finaldat1 <- data.frame(dat[, 3], dat[, 1], dat[, 2], 
                dat[,4:5], dat[, 7:8])
                miR <- finaldat1[, 2]
                ### Extracts miRNA function
                mfunct <- c()
                for (l in seq_along(miR)) {
                  pa <- paste("^", miR[l], "$", sep = "")
                  dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                    ignore.case = TRUE)
                  if (length(dd) == 1) {
                    mfunct <- c(mfunct, 
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                  } else {
                    mfunct <- c(mfunct, "NA")
                  }
                }
                ## Stores data in a data.frame
                finaldat1 <- cbind(finaldat1, mfunct, method = rep("Pearson", 
                    nrow(finaldat1)), row.names = NULL)
                names(finaldat1) <- c("FlybaseID", "miRNA", "GeneSymbol", 
                    "Genes_CGID", "Score", "Experiments", "TargetDatabase", 
                    "miRNAFunction", "Method")
            }
            
        } else if (identical(geneIDType, "CGID")) {
            
            dat <- Affy2_Pearson_Final[which(tolower(Affy2_Pearson_Final$CGID) %in% 
                tolower(gene)), ]
            if (nrow(dat) == 0) {
                stop("Records of the gene does not exist")
            } else {
                finaldat1 <- data.frame(dat[, 4], dat[, 1], dat[, 2:3], 
                dat[, 5], dat[, 7:8])
                miR <- finaldat1[, 2]
                ## Extracts miRNA function
                mfunct <- c()
                for (l in seq_along(miR)) {
                  pa <- paste("^", miR[l], "$", sep = "")
                  dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                    ignore.case = TRUE)
                  if (length(dd) == 1) {
                    mfunct <- c(mfunct, 
                    as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                  } else {
                    mfunct <- c(mfunct, "NA")
                  }
                }
                ## Stores data in a data.frame
                finaldat1 <- cbind(finaldat1, mfunct, method = rep("Pearson", 
                    nrow(finaldat1)), row.names = NULL)
                names(finaldat1) <- c("Gene_CGID", "miRNA", "GeneSymbol", 
                    "Genes_FBID", "Score", "Experiments", "TargetDatabase", 
                    "miRNAFunction", "Method")
            }
        } else {
            stop("GeneIdtype Invalid")
        }
        ## If text is chosen as TRUE
        if (identical(Text, TRUE)) {
            if (length(gene) > 1) {
                Genes <- paste(gene, collapse = "&")
            } else {
                Genes = gene
            }
            filename = paste("miRNAs_for_Genes_", Genes, "_", Platform, 
                "_", method, ".csv", sep = "")
            ## Checks files exists or not; if it does not exist write the .csv
            ## files.
            if (!(file.exists(file.path(outpath, filename)))) {
                write.csv(finaldat1, file = file.path(outpath, filename))
            } else {
                stop("File Already Exists!!")
            }
            
            
        } else {
            return(finaldat1)
        }
    } else if (identical(method, "Distance") & identical(Platform, "Affy1")) {
        if (identical(geneIDType, "GeneSymbol")) {
            ## Checks if the chosen geneIDType is GeneSymbol, FBGN or CGID else
            ## prints error message
            dat <- Affy1_Distance_Final[which(tolower
                (Affy1_Distance_Final$GeneSymbol) %in% tolower(gene)), ]
            if (nrow(dat) == 0) {
                stop("Records of the gene does not exist")
            } else {
                finaldat1 <- data.frame(dat[, 2], dat[, 1], dat[, 3:5], 
                    dat[, 7:8])
                miR <- finaldat1[, 2]
                ### Extracts miRNA function
                mfunct <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                    ignore.case = TRUE)
                  if (length(dd) == 1) {
                    mfunct <- c(mfunct, as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                  } else {
                    mfunct <- c(mfunct, "NA")
                  }
                }
                ### Stores data in a data.frame
                finaldat1 <- cbind(finaldat1, mfunct, method = rep("Pearson", 
                     nrow(finaldat1)), row.names = NULL)
                names(finaldat1) <- c("Gene", "miRNA", "Gene_FBID", 
                    "Genes_CGID", "Score", "Experiments", "TargetDatabase", 
                    "miRNAFunction", "Method")
            }
        } else if (identical(geneIDType, "FBGN")) {
            ### Extracts data when geneIDType is Flybase ID
            dat <- Affy1_Distance_Final[which(tolower(Affy1_Distance_Final$FBGN) %in% 
                tolower(gene)), ]
            if (nrow(dat) == 0) {
                stop("Records of the gene does not exist")
            } else {
                finaldat1 <- data.frame(dat[, 3], dat[, 1], dat[, 2], 
                dat[,4:5], dat[, 7:8])
                miR <- finaldat1[, 2]
                ## Extracting miRNA function
                mfunct <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                    ignore.case = TRUE)
                  if (length(dd) == 1) {
                    mfunct <- c(mfunct, 
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                  } else {
                    mfunct <- c(mfunct, "NA")
                  }
                }
                ## Storing Data in data.frame
                finaldat1 <- cbind(finaldat1, mfunct, method = rep("Pearson", 
                    nrow(finaldat1)), row.names = NULL)
                names(finaldat1) <- c("FlybaseID", "miRNA", "GeneSymbol", 
                    "Genes_CGID", "Score", "Experiments", "TargetDatabase", 
                    "miRNAFunction", "Method")
            }
        } else if (identical(geneIDType, "CGID")) {
            ### Extracts data when geneIDType is CGID
            dat <- Affy1_Distance_Final[which(tolower(Affy1_Distance_Final$CGID) %in% 
                tolower(gene)), ]
            if (nrow(dat) == 0) {
                stop("Records of the gene does not exist")
            } else {
                finaldat1 <- data.frame(dat[, 4], dat[, 1], dat[, 2:3], 
                  dat[, 5], dat[, 7:8])
                miR <- finaldat1[, 2]
                # Extracting the miRNA function
                mfunct <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                    ignore.case = TRUE)
                  if (length(dd) == 1) {
                    mfunct <- c(mfunct, 
                    as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                  } else {
                    mfunct <- c(mfunct, "NA")
                  }
                }
                ## Storing data
                finaldat1 <- cbind(finaldat1, mfunct, method = rep("Pearson", 
                    nrow(finaldat1)), row.names = NULL)
                names(finaldat1) <- c("Gene_CGID", "miRNA", "GeneSymbol", 
                    "Genes_FBID", "Score", "Experiments", "TargetDatabase", 
                    "miRNAFunction", "Method")
            }
        } else {
            stop("GeneIdtype Invalid")
        }
        if (identical(Text, TRUE)) {
            ## If text is chosen as TRUE; if not returns value to the console Checks
            ## if gene length>1; if yes adds & after each gene name
            if (length(gene) > 1) {
                Genes <- paste(gene, collapse = "&")
            } else {
                Genes = gene
            }
            filename = paste("miRNAs_for_Genes_", Genes, "_", Platform, 
                "_", method, ".csv", sep = "")
            
            if (!(file.exists(file.path(outpath, filename)))) {
                ## Checks if file exists; if not write the data in .csv
                write.csv(finaldat1, file = file.path(outpath, filename))
            } else {
                stop("File Already Exists!!")
            }
            
        } else {
            return(finaldat1)
        }
    } else if (identical(method, "Distance") & identical(Platform, "Affy2")) {
        ## Checks if the chosen geneIDType is GeneSymbol, FBGN or CGID else
        ## prints error message
        if (identical(geneIDType, "GeneSymbol")) {
            dat <- Affy2_Distance_Final[which
                    (tolower(Affy2_Distance_Final$GeneSymbol)
                    %in% tolower(gene)), ]
            if (nrow(dat) == 0) {
                stop("Records of the gene does not exist")
            } else {
                finaldat1 <- data.frame(dat[, 2], dat[, 1], dat[, 3:5], 
                dat[, 7:8])
                miR <- finaldat1[, 2]
                ## Extracting microRNA function
                mfunct <- c()
                for (l in seq_along(miR)) {
                  pa <- paste("^", miR[l], "$", sep = "")
                  dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                    ignore.case = TRUE)
                  if (length(dd) == 1) {
                    mfunct <- c(mfunct, 
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                  } else {
                    mfunct <- c(mfunct, "NA")
                  }
                }
                ### Storing Data
                finaldat1 <- cbind(finaldat1, mfunct, method = rep("Pearson", 
                  nrow(finaldat1)), row.names = NULL)
                names(finaldat1) <- c("Gene", "miRNA", "Gene_FBID", 
                    "Genes_CGID", "Score", "Experiments", "TargetDatabase",
                    "miRNAFunction", "Method")
            }
        } else if (identical(geneIDType, "FBGN")) {
            ### Extracts data when geneIDType is FLybase ID
            dat <- Affy2_Distance_Final[which
                    (tolower(Affy2_Distance_Final$FBGN) %in% tolower(gene)), ]
            if (nrow(dat) == 0) {
                stop("Records of the gene does not exist")
            } else {
                finaldat1 <- data.frame(dat[, 3], dat[, 1], dat[, 2], 
                    dat[, 4:5], dat[, 7:8])
                miR <- finaldat1[, 2]
                ## Extracting miRNA function
                mfunct <- c()
                for (l in seq_along(miR)) {
                  pa <- paste("^", miR[l], "$", sep = "")
                  dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                    ignore.case = TRUE)
                  if (length(dd) == 1) {
                    mfunct <- c(mfunct, 
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                  } else {
                        mfunct <- c(mfunct, "NA")
                  }
                }
                ## Storing data in the data.frame.
                finaldat1 <- cbind(finaldat1, mfunct, method = rep("Pearson", 
                    nrow(finaldat1)), row.names = NULL)
                names(finaldat1) <- c("FlybaseID", "miRNA", "GeneSymbol", 
                    "Genes_CGID", "Score", "Experiments", "TargetDatabase", 
                    "miRNAFunction", "Method")
            }
        } else if (identical(geneIDType, "CGID")) {
            ### Extracts data when geneIDType is CGID
            dat <- Affy2_Distance_Final[which(tolower(Affy2_Distance_Final$CGID) %in% 
                tolower(gene)), ]
            if (nrow(dat) == 0) {
                stop("Records of the gene does not exist")
            } else {
                finaldat1 <- data.frame(dat[, 4], dat[, 1], dat[, 2:3], 
                    dat[, 5], dat[, 7:8])
                miR <- finaldat1[, 2]
                ## Extracting miRNA function
                mfunct <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                            ignore.case = TRUE)
                  if (length(dd) == 1) {
                    mfunct <- c(mfunct, 
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                  } else {
                    mfunct <- c(mfunct, "NA")
                  }
                }
                ## Storing data in the data.frame.
                finaldat1 <- cbind(finaldat1, mfunct, method = rep("Pearson", 
                    nrow(finaldat1)), row.names = NULL)
                names(finaldat1) <- c("Gene_CGID", "miRNA", "GeneSymbol", 
                    "Genes_FBID", "Score", "Experiments", "TargetDatabase", 
                    "miRNAFunction", "Method")
            }
        } else {
            stop("GeneIdtype Invalid")
        }
        if (identical(Text, TRUE)) {
            ## If text is chosen as TRUE prints data in a .csv file else return the
            ## result to the console
            if (length(gene) > 1) {
                Genes <- paste(gene, collapse = "&")
            } else {
                Genes = gene
            }
            filename = paste("miRNAs_for_Genes_", Genes, "_", Platform, 
                "_", method, ".csv", sep = "")
            ## Check if file name exists. If not write it in the .csv file
            if (!(file.exists(file.path(outpath, filename)))) {
                write.csv(finaldat1, file = file.path(outpath, filename))
            } else {
                stop("File Already Exists!!")
            }
            
            
        } else {
            return(finaldat1)
        }
    } else if (identical(method, "Both") & identical(Platform, "Affy1")) {
        ## Checks if the chosen geneIDType is GeneSymbol, FBGN or CGID else
        ## prints error message
        if (identical(geneIDType, "GeneSymbol")) {
            # Extract data from Pearson and Distance respectively
            dat <- Affy1_Distance_Final[which(tolower(Affy1_Distance_Final$GeneSymbol) %in% 
                tolower(gene)), ]
            dat1 <- Affy1_Pearson_Final[which(tolower(Affy1_Pearson_Final$GeneSymbol) %in% 
                tolower(gene)), ]
            if (nrow(dat) == 0 | nrow(dat1) == 0) {
                stop("Records of the gene does not exist")
            } else {
                finaldat1 <- data.frame(Gene = dat[, 2], miRNA = dat[, 1],
                    dat[, 3:5], dat[, 7:8])
                finaldat2 <- data.frame(Gene = dat1[, 2], miRNA = dat1[, 1],
                    dat1[, 3:5], dat1[, 7:8])
                ## Extract miRNA function for Pearson and Distance respectively.
                miR <- finaldat1[, 2]
                mfunct <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                        ignore.case = TRUE)
                  if (length(dd) == 1) {
                        mfunct <- c(mfunct, 
                            as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                  } else {
                    mfunct <- c(mfunct, "NA")
                  }
                }
                miR <- finaldat2[, 2]
                mfunct1 <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                        ignore.case = TRUE)
                  if (length(dd) == 1) {
                    mfunct1 <- c(mfunct1, as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                  } else {
                    mfunct1 <- c(mfunct1, "NA")
                  }
                }
                ## Store data in data.frame
                finaldat2 <- cbind(finaldat2, mfunct = mfunct1, 
                    method = rep("Pearson", nrow(finaldat2)), row.names = NULL)
                finaldat1 <- cbind(finaldat1, mfunct = mfunct, method = rep("Distance", 
                    nrow(finaldat1)), row.names = NULL)
                finaldat <- rbind(finaldat1, finaldat2)
                    names(finaldat) <- c("Gene", "miRNA", "Gene_FBID",
                    "Genes_CGID", "Score", "Experiments", "TargetDatabase", 
                    "miRNAFunction", "Method")
            }
        } else if (identical(geneIDType, "FBGN")) {
            ### Extracts data when geneIDType is FBGN Extract data from Pearson and
            ### Distance respectively
            dat <- Affy1_Distance_Final[which(tolower(Affy1_Distance_Final$FBGN)
                    %in% tolower(gene)), ]
            dat1 <- Affy1_Pearson_Final[which(tolower(Affy1_Pearson_Final$FBGN)
                    %in% tolower(gene)), ]
            finaldat1 <- data.frame(Gene = dat[, 2], miRNA = dat[, 1], 
                    dat[, 3:5], dat[, 7:8])
            if (nrow(dat) == 0 | nrow(dat1) == 0) {
                    stop("Records of the gene does not exist")
            } else {
                finaldat2 <- data.frame(Gene = dat1[, 2], miRNA = dat1[, 1],
                    dat1[, 3:5], dat1[, 7:8])
                miR <- finaldat1[, 2]
                ## miRNA function extraction
                mfunct <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                        ignore.case = TRUE)
                if (length(dd) == 1) {
                    mfunct <- c(mfunct, as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                } else {
                    mfunct <- c(mfunct, "NA")
                }
                }
                miR <- finaldat2[, 2]
                mfunct1 <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                        ignore.case = TRUE)
                  if (length(dd) == 1) {
                        mfunct1 <- c(mfunct1, 
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                    } else {
                        mfunct1 <- c(mfunct1, "NA")
                    }
                }
                ### Storing data in form of data.frame
                finaldat2 <- cbind(finaldat2, mfunct = mfunct1,  
                        method = rep("Pearson",nrow(finaldat2)), 
                        row.names = NULL)
                finaldat1 <- cbind(finaldat1, mfunct = mfunct,  
                    method = rep("Distance", nrow(finaldat1)), 
                        row.names = NULL)
                finaldat <- rbind(finaldat1, finaldat2)
                names(finaldat) <- c("Gene", "miRNA", "Gene_FBID", "Genes_CGID", 
                    "Score", "Experiments", "TargetDatabase", "miRNAFunction", 
                    "Method")
            }
        } else if (identical(geneIDType, "CGID")) {
            ### Extracts data when geneIDType is CGID Extract data from Pearson and
            ### Distance respectively
            dat <- Affy1_Distance_Final[which(tolower(Affy1_Distance_Final$CGID)
                        %in% tolower(gene)), ]
            dat1 <- Affy1_Pearson_Final[which(tolower(Affy1_Pearson_Final$CGID)
                        %in% tolower(gene)), ]
            if (nrow(dat) == 0 | nrow(dat1) == 0) {
                stop("Records of the gene does not exist")
            } else {
                finaldat1 <- data.frame(Gene = dat[, 2], miRNA = dat[,1], 
                    dat[, 3:5], dat[, 7:8])
                finaldat2 <- data.frame(Gene = dat1[, 2], miRNA = dat1[, 1],
                    dat1[, 3:5], dat1[, 7:8])
                ## miRNA function extraction
                miR <- finaldat1[, 2]
                mfunct <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                        ignore.case = TRUE)
                  if (length(dd) == 1) {
                    mfunct <- c(mfunct, 
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                  } else {
                        mfunct <- c(mfunct, "NA")
                  }
                }
                miR <- finaldat2[, 2]
                mfunct1 <- c()
                for (l in seq_along(miR)) {
                  pa <- paste("^", miR[l], "$", sep = "")
                  dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                            ignore.case = TRUE)
                  if (length(dd) == 1) {
                    mfunct1 <- c(mfunct1, 
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                  } else {
                        mfunct1 <- c(mfunct1, "NA")
                  }
                }
                ## Storing data in data.frame
                finaldat2 <- cbind(finaldat2, mfunct = mfunct1, 
                  method = rep("Pearson", nrow(finaldat2)), row.names = NULL)
                finaldat1 <- cbind(finaldat1, mfunct = mfunct,  
                  method = rep("Distance",nrow(finaldat1)), row.names = NULL)
                finaldat <- rbind(finaldat1, finaldat2)
                names(finaldat) <- c("Gene", "miRNA", "Gene_FBID", "Genes_CGID", 
                  "Score", "Experiments", "TargetDatabase", "miRNAFunction", 
                  "Method")
            }
        } else {
            stop("GeneIdtype Invalid")
        }
        ## If text is selected as TRUE saved as .csv; else return to the console
        ## If length of gene is greater than 1
        if (identical(Text, TRUE)) {
            
            if (length(gene) > 1) {
                Genes <- paste(gene, collapse = "&")
            } else {
                Genes = gene
            }
            filename = paste("miRNAs_for_Genes_", Genes, "_", Platform, 
                "_", method, ".csv", sep = "")
            
            
            if (!(file.exists(file.path(outpath, filename)))) {
                ## Check if file name exists and print data.frame in .csv
                write.csv(finaldat, file = file.path(outpath, filename))
            } else {
                stop("File Already Exists!!")
            }
            
            
        } else {
            return(finaldat)
        }
    } else if (identical(method, "Both") & identical(Platform, "Affy2")) {
        ## Checks if the chosen geneIDType is GeneSymbol, FBGN or CGID else
        ## prints error message
        if (identical(geneIDType, "GeneSymbol")) {
            # Extract data from Pearson and Distance respectively
            dat <- Affy2_Distance_Final[which(tolower(Affy2_Distance_Final$GeneSymbol) %in% 
                tolower(gene)), ]
            dat1 <- Affy2_Pearson_Final[which(tolower(Affy2_Pearson_Final$GeneSymbol) %in% 
                tolower(gene)), ]
            if (nrow(dat) == 0 | nrow(dat1) == 0) {
                stop("Records of the gene does not exist")
            } else {
                finaldat1 <- data.frame(Gene = dat[, 2], miRNA = dat[, 1],
                    dat[, 3:5], dat[, 7:8])
                finaldat2 <- data.frame(Gene = dat1[, 2], miRNA = dat1[, 1],
                    dat1[, 3:5], dat1[, 7:8])
                miR <- finaldat1[, 2]
                ## Extract miRNA function for mPearson and Distance respectively.
                mfunct <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                        ignore.case = TRUE)
                  if (length(dd) == 1) {
                        mfunct <- c(mfunct, 
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                } else {
                    mfunct <- c(mfunct, "NA")
                  }
                }
                miR <- finaldat2[, 2]
                mfunct1 <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                        ignore.case = TRUE)
                    if (length(dd) == 1) {
                        mfunct1 <- c(mfunct1, 
                            as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                } else {
                    mfunct1 <- c(mfunct1, "NA")
                }
                }
                ## Storing data in data.frame
                finaldat2 <- cbind(finaldat2, mfunct = mfunct1,  
                        method = rep("Pearson", nrow(finaldat2)), 
                        row.names = NULL)
                finaldat1 <- cbind(finaldat1, mfunct = mfunct, 
                        method = rep("Distance", nrow(finaldat1)), 
                        row.names = NULL)
                finaldat <- rbind(finaldat1, finaldat2)
                names(finaldat) <- c("Gene", "miRNA", "Gene_FBID", "Genes_CGID", 
                    "Score", "Experiments", "TargetDatabase", "miRNAFunction", 
                    "Method")
            }
        } else if (identical(geneIDType, "FBGN")) {
            ### Extracts data when geneIDType is gene symbol
            dat <- Affy2_Distance_Final[which
                    (tolower(Affy2_Distance_Final$FBGN) %in% tolower(gene)), ]
            dat1 <- Affy2_Pearson_Final[which
                    (tolower(Affy2_Pearson_Final$FBGN) %in% 
                    tolower(gene)), ]
            if (nrow(dat) == 0 | nrow(dat1) == 0) {
                stop("Records of the gene does not exist")
            } else {
                finaldat1 <- data.frame(Gene = dat[, 2], miRNA = dat[, 1],
                    dat[, 3:5], dat[, 7:8])
                finaldat2 <- data.frame(Gene = dat1[, 2], miRNA = dat1[,1],
                    dat1[, 3:5], dat1[, 7:8])
                miR <- finaldat1[, 2]
                ## Extracts miRNA data
                mfunct <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                        ignore.case = TRUE)
                if (length(dd) == 1) {
                    mfunct <- c(mfunct, 
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                } else {
                    mfunct <- c(mfunct, "NA")
                }
                }
                miR <- finaldat2[, 2]
                mfunct1 <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                        ignore.case = TRUE)
                if (length(dd) == 1) {
                    mfunct1 <- c(mfunct1, 
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                } else {
                    mfunct1 <- c(mfunct1, "NA")
                }
                }
                ### Storing data in data.frame
                finaldat2 <- cbind(finaldat2, mfunct = mfunct1,  
                    method = rep("Pearson", nrow(finaldat2)), row.names = NULL)
                finaldat1 <- cbind(finaldat1, mfunct = mfunct,  
                    method = rep("Distance",nrow(finaldat1)), row.names = NULL)
                finaldat <- rbind(finaldat1, finaldat2)
                names(finaldat) <- c("Gene", "miRNA", "Gene_FBID", "Genes_CGID", 
                    "Score", "Experiments", "TargetDatabase", "miRNAFunction", 
                    "Method")
            }
        } else if (identical(geneIDType, "CGID")) {
            ### Extracts data when geneIDType is CGID Extracts data for Pearson and
            ### Distance respectively.
            dat <- Affy2_Distance_Final[which(tolower(Affy2_Distance_Final$CGID)
                %in% tolower(gene)), ]
            dat1 <- Affy2_Pearson_Final[which(tolower(Affy2_Pearson_Final$CGID)
                %in% tolower(gene)), ]
            if (nrow(dat) == 0 | nrow(dat1) == 0) {
                stop("Records of the gene does not exist")
            } else {
                finaldat1 <- data.frame(Gene = dat[, 2], miRNA = dat[, 1], 
                    dat[, 3:5], dat[, 7:8])
                finaldat2 <- data.frame(Gene = dat1[, 2], miRNA = dat1[, 1],
                    dat1[, 3:5], dat1[, 7:8])
                miR <- finaldat1[, 2]
                ### Extract data for miRNA function
                mfunct <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                        ignore.case = TRUE)
                if (length(dd) == 1) {
                    mfunct <- c(mfunct, as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                } else {
                    mfunct <- c(mfunct, "NA")
                }
                }
                miR <- finaldat2[, 2]
                mfunct1 <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                        ignore.case = TRUE)
                  if (length(dd) == 1) {
                    mfunct1 <- c(mfunct1, 
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                  } else {
                    mfunct1 <- c(mfunct1, "NA")
                  }
                }
                ### Storing data in data.frame
                finaldat2 <- cbind(finaldat2, mfunct = mfunct1,  
                        method = rep("Pearson",nrow(finaldat2)), 
                        row.names = NULL)
                finaldat1 <- cbind(finaldat1, mfunct = mfunct,  
                        method = rep("Distance", nrow(finaldat1)), 
                        row.names = NULL)
                finaldat <- rbind(finaldat1, finaldat2)
                names(finaldat) <- c("Gene", "miRNA", "Gene_FBID", 
                        "Genes_CGID", "Score", "Experiments",
                        "TargetDatabase", "miRNAFunction", 
                        "Method")
            }
        } else {
            stop("GeneIdtype Invalid")
        }
        if (identical(Text, TRUE)) {
            
            if (length(gene) > 1) {
                ### If text selected as TRUE; print data in .csv file else 
                ### print it on the console Checks if gene length>1; if yes
                ### adds & after each gene name
                Genes <- paste(gene, collapse = "&")
            } else {
                Genes = gene
            }
            filename = paste("miRNAs_for_Genes_", Genes, "_", Platform, 
                "_", method, ".csv", sep = "")
            ### Checking if File name exists and write data into .csv files
            if (!(file.exists(file.path(outpath, filename)))) {
                write.csv(finaldat, file = file.path(outpath, filename))
            } else {
                stop("File Already Exists!!")
            }
            
            
        } else {
            return(finaldat)
        }
        
    } else if (identical(method, "BothIntersect") & 
                identical(Platform, "Affy1")) {
        
        if (length(gene) > 1) {
            ## Checks whether the method is BothIntersect and platform 
            ## is Affy1 If length > 1
            finaldat <- data.frame()
            ## Checks if the chosen geneIDType is GeneSymbol, 
            ## FBGN or CGID elseprints error message
            if (identical(geneIDType, "GeneSymbol")) {
                for (ii in seq_along(gene)) {
                    dat <- Affy1_Distance_Final[which
                        (tolower(Affy1_Distance_Final$GeneSymbol) %in% 
                        tolower(gene[ii])), ]
                    dat1 <- Affy1_Pearson_Final[which
                        (tolower(Affy1_Pearson_Final$GeneSymbol) %in% 
                        tolower(gene[ii])), ]
                if (nrow(dat) == 0 | nrow(dat1) == 0) {
                    stop("Records of the gene does not exist")
                } else {
                    int <- intersect(as.character(dat$miRNA), 
                        as.character(dat1$miRNA))
                    fdat <- dat[which(tolower(dat$miRNA) %in% tolower(int)), ]
                    fdat1 <- dat1[which(tolower(dat1$miRNA) %in% 
                        tolower(int)), ]
                    dat_D <- data.frame(Gene = fdat[, 2], miRNA = fdat[, 1],
                        fdat[, 3:5], fdat[, 7:8])
                    dat_P <- data.frame(Gene = fdat1[, 2], miRNA = fdat1[, 1], 
                        fdat1[, 3:5], fdat1[, 7:8])
                    ## Extracting the miRNA function
                    miR <- int
                    mfunct <- c()
                    for (l in seq_along(miR)) {
                        pa <- paste("^", miR[l], "$", sep = "")
                        dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                            ignore.case = TRUE)
                    if (length(dd) == 1) {
                        mfunct <- c(mfunct, as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                    } else {
                        mfunct <- c(mfunct, "NA")
                    }
                    }
                    finaldat1 <- cbind(Gene = dat_P[, 2], miRNA = dat_P[, 1], 
                        dat_P[, 3:5], DistanceScore = dat_D[, 5], 
                        Pexp = dat_P[, 6], Dexp = dat_D[, 6], 
                        TargetDB = dat_P[, 7], Genefunc = mfunct)
                    finaldat <- rbind(finaldat, finaldat1)
                    }
                }
                ## Storing the data in the data.frame
                finaldat <- cbind(finaldat, method = rep("PearsonDistance", 
                        nrow(finaldat)))
                names(finaldat) <- c("Gene", "miRNA", "Gene_FBID", "Genes_CGID", 
                    "Pearson_Score", "Distance_Score", "PearsonExperiments", 
                    "DistanceExperiments", "TargetDatabase", "miRNAFunction", 
                    "Method")
            } else if (identical(geneIDType, "FBGN")) {
                ### If geneIDtype selected as FBGN Extracting data from Pearson and
                ### Distance and finding the common microRNAs between them and extracting
                ### data individually for the intersected miRNAs.
                for (ii in seq_along(gene)) {
                    dat <- Affy1_Distance_Final[which(tolower(Affy1_Distance_Final$FBGN) %in% 
                        tolower(gene[ii])), ]
                    dat1 <- Affy1_Pearson_Final[which(tolower(Affy1_Pearson_Final$FBGN) %in% 
                        tolower(gene[ii])), ]
                    if (nrow(dat) == 0 | nrow(dat1) == 0) {
                        stop("Records of the gene does not exist")
                    } else {
                    int <- intersect(as.character(dat$miRNA), 
                        as.character(dat1$miRNA))
                    fdat <- dat[which(tolower(dat$miRNA) %in%  
                        tolower(int)),]
                    fdat1 <- dat1[which(tolower(dat1$miRNA) %in%  
                        tolower(int)),]
                    dat_D <- data.frame(Gene = fdat[, 2], miRNA = fdat[, 1],
                        fdat[, 3:5], fdat[, 7:8])
                    dat_P <- data.frame(Gene = fdat1[, 2], miRNA = fdat1[, 1],
                        fdat1[, 3:5], fdat1[, 7:8])
                    miR <- int
                    ### miRNA function extraction
                    mfunct <- c()
                    for (l in seq_along(miR)) {
                        pa <- paste("^", miR[l], "$", sep = "")
                        dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                            ignore.case = TRUE)
                    if (length(dd) == 1) {
                        mfunct <- c(mfunct, as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                    } else {
                        mfunct <- c(mfunct, "NA")
                        }
                    }
                    ### Storing data in data.frame
                    finaldat1 <- cbind(Gene = dat_P[, 3], miRNA = dat_P[,1], 
                        GS = dat_P[, 2], dat_P[, 4:5],  
                        DistanceScore = dat_D[,5], Pexp = dat_P[, 6], 
                        Dexp = dat_D[, 6], TargetDB = dat_P[, 7], 
                        Genefunc = mfunct)
                    finaldat <- rbind(finaldat, finaldat1)
                  }
                }
                finaldat <- cbind(finaldat, method = rep("PearsonDistance", 
                    nrow(finaldat)))
                names(finaldat) <- c("FBID", "miRNA", "Gene_Symbol", "Genes_CGID", 
                    "Pearson_Score", "Distance_Score", "PearsonExperiments", 
                    "DistanceExperiments", "TargetDatabase", "miRNAFunction", 
                    "Method")
            } else if (identical(geneIDType, "CGID")) {
                for (ii in seq_along(gene)) {
                    dat <- Affy1_Distance_Final[ 
                    which(tolower(Affy1_Distance_Final$CGID) %in%
                    tolower(gene[ii])), ]
                    dat1 <- Affy1_Pearson_Final[which
                    (tolower(Affy1_Pearson_Final$CGID) %in% 
                    tolower(gene[ii])), ]
                if (nrow(dat) == 0 | nrow(dat1) == 0) {
                    stop("Records of the gene does not exist")
                } else {
                    int <- intersect(as.character(dat$miRNA), 
                        as.character(dat1$miRNA))
                    fdat <- dat[which(tolower(dat$miRNA)
                        %in% tolower(int)),]
                    fdat1 <- dat1[which(tolower(dat1$miRNA) 
                        %in% tolower(int)), ]
                    dat_D <- data.frame(Gene = fdat[, 2], miRNA = fdat[, 1], 
                        fdat[, 3:5], fdat[, 7:8])
                    dat_P <- data.frame(Gene = fdat1[, 2], miRNA = fdat1[, 1], 
                        fdat1[, 3:5], fdat1[, 7:8])
                    miR <- int
                    ### miRNA function extraction
                    mfunct <- c()
                    for (l in seq_along(miR)) {
                      pa <- paste("^", miR[l], "$", sep = "")
                      dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                        ignore.case = TRUE)
                    if (length(dd) == 1) {
                        mfunct <- c(mfunct, 
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                    } else {
                        mfunct <- c(mfunct, "NA")
                        }
                    }
                    ### Storing data in data.frame
                    finaldat1 <- cbind(Gene = dat_P[, 4], miRNA = dat_P[, 1],
                        dat_P[, 2:3], PearsonScore = dat_P[, 5],  
                        DistanceScore = dat_D[, 5], Genefunc = mfunct, 
                        Pexp = dat_P[, 6], Dexp = dat_D[, 6], 
                        TargetDB = dat_P[, 7])
                    finaldat <- rbind(finaldat, finaldat1)
                    }
                }
                finaldat <- cbind(finaldat, method = rep("PearsonDistance", 
                    nrow(finaldat)))
                names(finaldat) <- c("CGID", "miRNA", "Gene_Symbol", "Genes_FBID", 
                    "Pearson_Score", "Distance_Score", "PearsonExperiments", 
                    "DistanceExperiments", "TargetDatabase", "miRNAFunction", 
                    "Method")
            } else {
                stop("GeneIdtype Invalid")
                }
        } else {
            ### If length of miRNA == 1 Checks if the chosen geneIDType is
            ### GeneSymbol, FBGN or CGID else prints error message
            
            if (identical(geneIDType, "GeneSymbol")) {
                ### If geneIDtype selected as GeneSymbol Extracting data from Pearson and
                ### Distance and finding the common microRNAs between them and extracting
                ### data individually for the intersected miRNAs.
                dat <- Affy1_Distance_Final[
                    which(tolower(Affy1_Distance_Final$GeneSymbol) %in% 
                    tolower(gene)), ]
                dat1 <- Affy1_Pearson_Final[
                    which(tolower(Affy1_Pearson_Final$GeneSymbol) %in%
                    tolower(gene)), ]
                if (nrow(dat) == 0 | nrow(dat1) == 0) {
                    stop("Records of the gene does not exist")
                } else {
                    int <- intersect(as.character(dat$miRNA), 
                        as.character(dat1$miRNA))
                    fdat <- dat[which(tolower(dat$miRNA) %in% tolower(int)), ]
                    fdat1 <- dat1[which(tolower(dat1$miRNA) %in% tolower(int)), ]
                    dat_D <- data.frame(Gene = fdat[, 2], miRNA = fdat[, 1],
                        fdat[, 3:5], fdat[, 7:8])
                    dat_P <- data.frame(Gene = fdat1[, 2], miRNA = fdat1[, 1],
                        fdat1[, 3:5], fdat1[, 7:8])
                    miR <- int
                    ## Extracting miRNA function
                    mfunct <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                      ignore.case = TRUE)
                    if (length(dd) == 1) {
                        mfunct <- c(mfunct, 
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                    } else {
                      mfunct <- c(mfunct, "NA")
                        }
                }
                  
                  ### Storing data in data.frame
                    finaldat <- cbind(Gene = dat_P[, 2], miRNA = dat_P[,1], 
                    dat_P[, 3:5], DistanceScore = dat_D[, 5], 
                    Genefunc = mfunct, Pexp = dat_P[, 6], Dexp = dat_D[, 6], 
                    TargetDB = dat_P[, 7])
                    finaldat <- cbind(finaldat, method = rep("PearsonDistance", 
                    nrow(finaldat)))
                    names(finaldat) <- c("Gene", "miRNA", "Gene_FBID", "Genes_CGID", 
                    "Pearson_Score", "Distance_Score", "PearsonExperiments", 
                    "DistanceExperiments", "TargetDatabase", "miRNAFunction", 
                    "Method")
                }
            } else if (identical(geneIDType, "FBGN")) {
                ### If geneIDtype selected as FBGN Extracting data from Pearson and
                ### Distance and finding the common microRNAs between them and extracting
                ### data individually for the intersected miRNAs.
                dat <- Affy1_Distance_Final[which(tolower
                    (Affy1_Distance_Final$FBGN) %in% 
                    tolower(gene)), ]
                dat1 <- Affy1_Pearson_Final[which
                    (tolower(Affy1_Pearson_Final$FBGN) %in% 
                    tolower(gene)), ]
                if (nrow(dat) == 0 | nrow(dat1) == 0) {
                    stop("Records of the gene does not exist")
                } else {
                    int <- intersect(as.character(dat$miRNA),
                        as.character(dat1$miRNA))
                    fdat <- dat[which(tolower(dat$miRNA) %in% tolower(int)), ]
                    fdat1 <- dat1[which(tolower(dat1$miRNA) %in% 
                    tolower(int)), ]
                    dat_D <- data.frame(Gene = fdat[, 2], miRNA = fdat[, 1],
                    fdat[, 3:5], fdat[, 7:8])
                    dat_P <- data.frame(Gene = fdat1[, 2], miRNA = fdat1[, 1],
                    fdat1[, 3:5], fdat1[, 7:8])
                    miR <- int
                  ## miRNA extraction for function
                  mfunct <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                        ignore.case = TRUE)
                    if (length(dd) == 1) {
                        mfunct <- c(mfunct, as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                    } else {
                      mfunct <- c(mfunct, "NA")
                    }
                }
                  ## Storing final data
                finaldat <- cbind(Gene = dat_P[, 3], miRNA = dat_P[, 1],
                GS = dat_P[, 2], dat_P[, 4:5], DistanceScore = dat_D[, 5], 
                Genefunc = mfunct, Pexp = dat_P[, 6], Dexp = dat_D[, 6],
                TargetDB = dat_P[, 7])
                finaldat <- cbind(finaldat, method = rep("PearsonDistance", 
                nrow(finaldat)))
                names(finaldat) <- c("FBID", "miRNA", "Gene_Symbol", 
                "Genes_CGID", "Pearson_Score", "Distance_Score", 
                "PearsonExperiments", "DistanceExperiments", "TargetDatabase",
                "miRNAFunction", "Method")
                }
            } else if (identical(geneIDType, "CGID")) {
                ### If geneIDtype selected as CGID Extracting data from Pearson and
                ### Distance and finding the common microRNAs between them and extracting
                ### data individually for the intersected miRNAs.
                dat <- Affy1_Distance_Final[which
                    (tolower(Affy1_Distance_Final$CGID) %in% tolower(gene)), ]
                dat1 <- Affy1_Pearson_Final[
                    which(tolower(Affy1_Pearson_Final$CGID) 
                    %in% tolower(gene)), ]
                if (nrow(dat) == 0 | nrow(dat1) == 0) {
                    stop("Records of the gene does not exist")
                } else {
                    int <- intersect(as.character(dat$miRNA),
                        as.character(dat1$miRNA))
                    fdat <- dat[which(tolower(dat$miRNA) %in% tolower(int)), ]
                    fdat1 <- dat1[which(tolower(dat1$miRNA) %in% 
                    tolower(int)), ]
                    dat_D <- data.frame(Gene = fdat[, 2], miRNA = fdat[, 1], 
                        fdat[, 3:5], fdat[, 7:8])
                    dat_P <- data.frame(Gene = fdat1[, 2], miRNA = fdat1[, 1],
                    fdat1[, 3:5], fdat1[, 7:8])
                    miR <- int
                    ## Extracting miRNA function
                    mfunct <- c()
                for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                        ignore.case = TRUE)
                    if (length(dd) == 1) {
                        mfunct <- c(mfunct, 
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                    } else {
                        mfunct <- c(mfunct, "NA")
                    }
                }
                    ### Storing data in data.frame
                    finaldat <- cbind(Gene = dat_P[, 4], miRNA = dat_P[, 1], 
                    dat_P[, 2:3], PearsonScore = dat_P[, 5],  
                    DistanceScore = dat_D[,5], Genefunc = mfunct, 
                    Pexp = dat_P[, 6], Dexp = dat_D[, 6],
                    TargetDB = dat_P[, 7], Genefunc = mfunct)
                    finaldat <- cbind(finaldat, method = rep("PearsonDistance", 
                    nrow(finaldat)))
                    names(finaldat) <- c("CGID", "miRNA", "Gene_Symbol", 
                    "Genes_FBID", "Pearson_Score", "Distance_Score", 
                    "PearsonExperiments", "DistanceExperiments", 
                    "TargetDatabase", "miRNAFunction", "Method")
                  
                }
            } else {
                stop("GeneIdtype Invalid")
            }
            ### If text selected as TRUE; print data in .csv file else print it on
            ### the console Checks if gene length>1; if yes adds & after each gene
            ### name
            if (identical(Text, TRUE)) {
                
                if (length(gene) > 1) {
                    Genes <- paste(gene, collapse = "&")
                } else {
                    Genes = gene
                }
                filename = paste("miRNAs_for_Genes_", Genes, "_", Platform, 
                    "_", method, ".csv", sep = "")
                ### Checking if File name exists and write data into .csv files
                if (!(file.exists(file.path(outpath, filename)))) {
                    write.csv(finaldat, file = file.path(outpath, filename))
                } else {
                    stop("File Already Exists!!")
                }
                
                
            } else {
                return(finaldat)
            }
        }
    } else if (identical(method, "BothIntersect") & identical(Platform, "Affy2")) {
        
        ## length of gene > 1
        if (length(gene) > 1) {
            finaldat <- data.frame()
            ## Checks if the chosen geneIDType is GeneSymbol, FBGN or CGID else
            ## prints error message
            if (identical(geneIDType, "GeneSymbol")) {
                ## Extracting data from Pearson and Distance and finding the common
                ## microRNAs between them and extracting data individually for the
                ## intersected miRNAs.
                for (ii in seq_along(gene)) {
                    dat <- Affy2_Distance_Final[which
                        (tolower(Affy2_Distance_Final$GeneSymbol) %in% 
                        tolower(gene[ii])), ]
                    dat1 <- Affy2_Pearson_Final[which
                        (tolower(Affy2_Pearson_Final$GeneSymbol) %in% 
                        tolower(gene[ii])), ]
                    if (nrow(dat) == 0 | nrow(dat1) == 0) {
                        stop("Records of the gene does not exist")
                } else {
                    int <- intersect(as.character(dat$miRNA), 
                        as.character(dat1$miRNA))
                    fdat <- dat[which(tolower(dat$miRNA) %in% tolower(int)), ]
                    fdat1 <- dat1[which(tolower(dat1$miRNA) 
                        %in% tolower(int)), ]
                    dat_D <- data.frame(Gene = fdat[, 2], miRNA = fdat[, 1],
                        fdat[, 3:5], fdat[, 7:8])
                    dat_P <- data.frame(Gene = fdat1[, 2], miRNA = fdat1[, 1],
                        fdat1[, 3:5], fdat1[, 7:8])
                    miR <- int
                    ### Extracting miRNA function
                    mfunct <- c()
                    for (l in seq_along(miR)) {
                        pa <- paste("^", miR[l], "$", sep = "")
                        dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                        ignore.case = TRUE)
                    if (length(dd) == 1) {
                         mfunct <- c(mfunct,
                        as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                    } else {
                        mfunct <- c(mfunct, "NA")
                      }
                    }
                    # Storing data in data.frame
                    finaldat1 <- cbind(Gene = dat_P[, 2], miRNA = dat_P[, 
                      1], dat_P[, 3:5], DistanceScore = dat_D[, 5], Genefunc = mfunct, 
                      Pexp = dat_P[, 6], Dexp = dat_D[, 6], TargetDB = dat_P[, 
                        7], Genefunc = mfunct)
                    finaldat <- rbind(finaldat, finaldat1)
                  }
                }
                
                finaldat <- cbind(finaldat, method = rep("PearsonDistance", 
                  nrow(finaldat)))
                names(finaldat) <- c("Gene", "miRNA", "Gene_FBID", "Genes_CGID", 
                  "Pearson_Score", "Distance_Score", "PearsonExperiments", 
                  "DistanceExperiments", "TargetDatabase", "miRNAFunction", 
                  "Method")
            } else if (identical(geneIDType, "FBGN")) {
                ### If geneIDtype selected as FBGN Extracting data from Pearson and
                ### Distance and finding the common microRNAs between them and extracting
                ### data individually for the intersected miRNAs.
                for (ii in seq_along(gene)) {
                  dat <- Affy2_Distance_Final[which(tolower(Affy2_Distance_Final$FBGN) %in% 
                    tolower(gene[ii])), ]
                  dat1 <- Affy2_Pearson_Final[which(tolower(Affy2_Pearson_Final$FBGN) %in% 
                    tolower(gene[ii])), ]
                  if (nrow(dat) == 0 | nrow(dat1) == 0) {
                    print("Records of the gene does not exist")
                  } else {
                    int <- intersect(as.character(dat$miRNA), as.character(dat1$miRNA))
                    fdat <- dat[which(tolower(dat$miRNA) %in% tolower(int)), 
                      ]
                    fdat1 <- dat1[which(tolower(dat1$miRNA) %in% tolower(int)), 
                      ]
                    dat_D <- data.frame(Gene = fdat[, 2], miRNA = fdat[, 
                      1], fdat[, 3:5], fdat[, 7:8])
                    dat_P <- data.frame(Gene = fdat1[, 2], miRNA = fdat1[, 
                      1], fdat1[, 3:5], fdat1[, 7:8])
                    miR <- int
                    ## Extracting miRNA function
                    mfunct <- c()
                    for (l in seq_along(miR)) {
                      pa <- paste("^", miR[l], "$", sep = "")
                      dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                        ignore.case = TRUE)
                      if (length(dd) == 1) {
                        mfunct <- c(mfunct, as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                      } else {
                        mfunct <- c(mfunct, "NA")
                      }
                    }
                    ### Storing data in data.frame
                    finaldat1 <- cbind(Gene = dat_P[, 3], miRNA = dat_P[, 
                      1], GS = dat_P[, 2], dat_P[, 4:5], DistanceScore = dat_D[, 
                      5], Pexp = dat_P[, 6], Dexp = dat_D[, 6], TargetDB = dat_P[, 
                      7], Genefunc = mfunct)
                    finaldat <- rbind(finaldat, finaldat1)
                  }
                }
                finaldat <- cbind(finaldat, method = rep("PearsonDistance", 
                  nrow(finaldat)))
                names(finaldat) <- c("FBID", "miRNA", "Gene_Symbol", "Genes_CGID", 
                  "Pearson_Score", "Distance_Score", "PearsonExperiments", 
                  "DistanceExperiments", "TargetDatabase", "miRNAFunction", 
                  "Method")
            } else if (identical(geneIDType, "CGID")) {
                ### If geneIDtype selected as CGID Extracting data from Pearson and
                ### Distance and finding the common microRNAs between them and extracting
                ### data individually for the intersected miRNAs.
                for (ii in seq_along(gene)) {
                  dat <- Affy2_Distance_Final[which(tolower(Affy2_Distance_Final$CGID) %in% 
                    tolower(gene[ii])), ]
                  dat1 <- Affy2_Pearson_Final[which(tolower(Affy2_Pearson_Final$CGID) %in% 
                    tolower(gene[ii])), ]
                  if (nrow(dat) == 0 | nrow(dat1) == 0) {
                    print("Records of the gene does not exist")
                  } else {
                    int <- intersect(as.character(dat$miRNA), as.character(dat1$miRNA))
                    fdat <- dat[which(tolower(dat$miRNA) %in% tolower(int)), 
                      ]
                    fdat1 <- dat1[which(tolower(dat1$miRNA) %in% tolower(int)), 
                      ]
                    dat_D <- data.frame(Gene = fdat[, 2], miRNA = fdat[, 
                      1], fdat[, 3:5], fdat[, 7:8])
                    dat_P <- data.frame(Gene = fdat1[, 2], miRNA = fdat1[, 
                      1], fdat1[, 3:5], fdat1[, 7:8])
                    miR <- int
                    ### miRNA function extraction
                    mfunct <- c()
                    for (l in seq_along(miR)) {
                      pa <- paste("^", miR[l], "$", sep = "")
                      dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                        ignore.case = TRUE)
                      if (length(dd) == 1) {
                        mfunct <- c(mfunct, as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                      } else {
                        mfunct <- c(mfunct, "NA")
                      }
                    }
                    ### Data stored in final data
                    finaldat1 <- cbind(Gene = dat_P[, 4], miRNA = dat_P[, 
                      1], dat_P[, 2:3], PearsonScore = dat_P[, 5], DistanceScore = dat_D[, 
                      5], Pexp = dat_P[, 6], Dexp = dat_D[, 6], TargetDB = dat_P[, 
                      7], Genefunc = mfunct)
                    finaldat <- rbind(finaldat, finaldat1)
                  }
                }
                finaldat <- cbind(finaldat, method = rep("PearsonDistance", 
                  nrow(finaldat)))
                names(finaldat) <- c("CGID", "miRNA", "Gene_Symbol", "Genes_FBID", 
                  "Pearson_Score", "Distance_Score", "PearsonExperiments", 
                  "DistanceExperiments", "TargetDatabase", "miRNAFunction", 
                  "Method")
            } else {
                stop("File Already Exists!!")
            }
        } else {
            ## Checks if the chosen geneIDType is GeneSymbol, FBGN or CGID else
            ## prints error message
            if (identical(geneIDType, "GeneSymbol")) {
                ### If geneIDtype selected as GeneSymbol Extracting data from Pearson and
                ### Distance and finding the common microRNAs between them and extracting
                ### data individually for the intersected miRNAs.
                dat <- Affy2_Distance_Final[which(tolower(Affy2_Distance_Final$GeneSymbol) %in% 
                  tolower(gene)), ]
                dat1 <- Affy2_Pearson_Final[which(tolower(Affy2_Pearson_Final$GeneSymbol) %in% 
                  tolower(gene)), ]
                if (nrow(dat) == 0 | nrow(dat1) == 0) {
                  print("Records of the gene does not exist")
                } else {
                  int <- intersect(as.character(dat$miRNA), as.character(dat1$miRNA))
                  fdat <- dat[which(tolower(dat$miRNA) %in% tolower(int)), 
                    ]
                  fdat1 <- dat1[which(tolower(dat1$miRNA) %in% tolower(int)), 
                    ]
                  dat_D <- data.frame(Gene = fdat[, 2], miRNA = fdat[, 
                    1], fdat[, 3:5], fdat[, 7:8])
                  dat_P <- data.frame(Gene = fdat1[, 2], miRNA = fdat1[, 
                    1], fdat1[, 3:5], fdat1[, 7:8])
                  miR <- int
                  ### Extracting miRNA function
                  mfunct <- c()
                  for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                      ignore.case = TRUE)
                    if (length(dd) == 1) {
                      mfunct <- c(mfunct, as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                    } else {
                      mfunct <- c(mfunct, "NA")
                    }
                  }
                  ### Storing data in the data.frame
                  finaldat <- cbind(Gene = dat_P[, 2], miRNA = dat_P[, 
                    1], dat_P[, 3:5], DistanceScore = dat_D[, 5], Genefunc = mfunct, 
                    Pexp = dat_P[, 6], Dexp = dat_D[, 6], TargetDB = dat_P[, 
                      7], Genefunc = mfunct)
                  finaldat <- cbind(finaldat, method = rep("PearsonDistance", 
                    nrow(finaldat)))
                  names(finaldat) <- c("Gene", "miRNA", "Gene_FBID", "Genes_CGID", 
                    "Pearson_Score", "Distance_Score", "PearsonExperiments", 
                    "DistanceExperiments", "TargetDatabase", "miRNAFunction", 
                    "Method")
                }
            } else if (identical(geneIDType, "FBGN")) {
                ### If geneIDtype selected as FBGN Extracting data from Pearson and
                ### Distance and finding the common microRNAs between them and extracting
                ### data individually for the intersected miRNAs.
                dat <- Affy2_Distance_Final[which(tolower(Affy2_Distance_Final$FBGN) %in% 
                  tolower(gene)), ]
                dat1 <- Affy2_Pearson_Final[which(tolower(Affy2_Pearson_Final$FBGN) %in% 
                  tolower(gene)), ]
                if (nrow(dat) == 0 | nrow(dat1) == 0) {
                  print("Records of the gene does not exist")
                } else {
                  int <- intersect(as.character(dat$miRNA), as.character(dat1$miRNA))
                  fdat <- dat[which(tolower(dat$miRNA) %in% tolower(int)), 
                    ]
                  fdat1 <- dat1[which(tolower(dat1$miRNA) %in% tolower(int)), 
                    ]
                  dat_D <- data.frame(Gene = fdat[, 2], miRNA = fdat[, 
                    1], fdat[, 3:5], fdat[, 7:8])
                  dat_P <- data.frame(Gene = fdat1[, 2], miRNA = fdat1[, 
                    1], fdat1[, 3:5], fdat1[, 7:8])
                  miR <- int
                  ### Extracting microRNA function
                  mfunct <- c()
                  for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                      ignore.case = TRUE)
                    if (length(dd) == 1) {
                      mfunct <- c(mfunct, as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                    } else {
                      mfunct <- c(mfunct, "NA")
                    }
                  }
                  ### Storing data in data.frame
                  finaldat <- cbind(Gene = dat_P[, 3], miRNA = dat_P[, 
                    1], GS = dat_P[, 2], dat_P[, 4:5], DistanceScore = dat_D[, 
                    5], Pexp = dat_P[, 6], Dexp = dat_D[, 6], TargetDB = dat_P[, 
                    7], Genefunc = mfunct)
                  finaldat <- cbind(finaldat, method = rep("PearsonDistance", 
                    nrow(finaldat)))
                  names(finaldat) <- c("FBID", "miRNA", "Gene_Symbol", 
                    "Genes_CGID", "Pearson_Score", "Distance_Score", "PearsonExperiments", 
                    "DistanceExperiments", "TargetDatabase", "miRNAFunction", 
                    "Method")
                }
            } else if (identical(geneIDType, "CGID")) {
                ### If geneIDtype selected as CGID Extracting data from Pearson and
                ### Distance and finding the common microRNAs between them and extracting
                ### data individually for the intersected miRNAs.
                dat <- Affy2_Distance_Final[which(tolower(Affy2_Distance_Final$CGID) %in% 
                  tolower(gene)), ]
                dat1 <- Affy2_Pearson_Final[which(tolower(Affy2_Pearson_Final$CGID) %in% 
                  tolower(gene)), ]
                if (nrow(dat) == 0 | nrow(dat1) == 0) {
                  print("Records of the gene does not exist")
                } else {
                  int <- intersect(as.character(dat$miRNA), as.character(dat1$miRNA))
                  fdat <- dat[which(tolower(dat$miRNA) %in% tolower(int)), 
                    ]
                  fdat1 <- dat1[which(tolower(dat1$miRNA) %in% tolower(int)), 
                    ]
                  dat_D <- data.frame(Gene = fdat[, 2], miRNA = fdat[, 
                    1], fdat[, 3:5], fdat[, 7:8])
                  dat_P <- data.frame(Gene = fdat1[, 2], miRNA = fdat1[, 
                    1], fdat1[, 3:5], fdat1[, 7:8])
                  miR <- int
                  ### Extracting miRNA functional data
                  mfunct <- c()
                  for (l in seq_along(miR)) {
                    pa <- paste("^", miR[l], "$", sep = "")
                    dd <- grep(pa, as.character(miRNA_ID_to_Function$miRNA), 
                      ignore.case = TRUE)
                    if (length(dd) == 1) {
                      mfunct <- c(mfunct, as.character(miRNA_ID_to_Function$miRNAFunction[dd]))
                    } else {
                      mfunct <- c(mfunct, "NA")
                    }
                  }
                  ### Storing final data
                  finaldat <- cbind(Gene = dat_P[, 4], miRNA = dat_P[, 
                    1], dat_P[, 2:3], PearsonScore = dat_P[, 5], DistanceScore = dat_D[, 
                    5], Genefunc = mfunct, Pexp = dat_P[, 6], Dexp = dat_D[, 
                    6], TargetDB = dat_P[, 7], Genefunc = mfunct)
                  finaldat <- cbind(finaldat, method = rep("PearsonDistance", 
                    nrow(finaldat)))
                  names(finaldat) <- c("CGID", "miRNA", "Gene_Symbol", 
                    "Genes_FBID", "Pearson_Score", "Distance_Score", "PearsonExperiments", 
                    "DistanceExperiments", "TargetDatabase", "miRNAFunction", 
                    "Method")
                  
                }
            } else {
                stop("File Already Exists!!")
            }
            ## If text is chosen as TRUE; if not returns value to the console Checks
            ## if gene length>1; if yes adds & after each gene name
            if (identical(Text, TRUE)) {
                
                if (length(gene) > 1) {
                  Genes <- paste(gene, collapse = "&")
                } else {
                  Genes = gene
                }
                filename = paste("miRNAs_for_Genes_", Genes, "_", Platform, 
                  "_", method, ".csv", sep = "")
                ### Checking whether file name exists amd writing data in .csv file
                if (!(file.exists(file.path(outpath, filename)))) {
                  write.csv(finaldat, file = file.path(outpath, filename))
                } else {
                  stop("File Already Exists!!")
                }
                
                
            } else {
                return(finaldat)
            }
        }
    } else {
        print("Method and/or Platform does not exist")
    }
    
}

#' Extracting miRNAs that target a query gene.
#'
#' @param miR  character. miRNA symbol.
#' @param method  character. Choices are "Pearson", "Distance","Both" 
#'                and "BothIntersected"
#' @param Platform  character. Choices are "Affy1","Affy2".
#'                
#' @param Text  logical . To choose between storing the data as text file.
#'              Default is FALSE.
#' @param outpath  character. The path where the data is stored if TEXT=TRUE.
#'                 Default is tempdir().
#' @return Outputs the target information, Target Prediction Score, miRNA 
#'         target function and Target Database that predicts the interaction in
#'         a dataframe.
#'         Depending upon the ouput choice data is stored in the
#'         path specified. Default option prints output to the console. 
#' @examples
#' miRNA="dme-miR-12"
#' miRTargets_Stat (miRNA,method=c ("Pearson"),Platform=c ("Affy1"),Text=FALSE)
#' @import utils grDevices graphics 
#' @importFrom stats na.omit
#' @export 

miRTargets_Stat <- function(miR, method = c("Pearson", "Distance", "Both", 
    "BothIntersect"), Platform = c("Affy1", "Affy2"), outpath = tempdir(), 
    Text = FALSE) {
    ### Loading the Datasets & Initialising Variables
    Affy2_Distance_Final <- c()
    Affy1_Distance_Final <- c()
    Affy2_Pearson_Final <- c()
    Affy1_Pearson_Final <- c()
    data("Affy1_Pearson_Final", envir = environment())
    Affy1_Pearson_Final <- Affy1_Pearson_Final
    data("Affy1_Distance_Final", envir = environment())
    Affy1_Distance_Final <- Affy1_Distance_Final
    data("Affy2_Pearson_Final", envir = environment())
    Affy2_Pearson_Final <- Affy2_Pearson_Final
    data("Affy2_Distance_Final", envir = environment())
    Affy2_Distance_Final <- Affy2_Distance_Final
    ### Checking if input variables are valid
    stopifnot(is.character(miR), length(miR) > 0, 
        length(extract_HostGene(miR)) > 0)
    # stopifnot(is.character(geneIDType), length(geneIDType) > 0)
    stopifnot(is.character(method), length(method) > 0, 
        method %in% c("Pearson", "Distance", "Both", "BothIntersect"))
    stopifnot(is.character(Platform), length(Platform) > 0, Platform %in% 
        c("Affy1", "Affy2"))
    ## Checks the method, the platform and geneIDType and extracts the data
    ## for each individual query gene.  First Checks whether the method is
    ## Pearson and platform is Affy1 Else Checks If the method is is Pearson
    ## and platform is Affy2 Else Checks If the method is is Distance and
    ## platform is Affy1 Else Checks If the method is is Distance and
    ## platform is Affy2 Else Checks If the method is is Both and platform
    ## is Affy1 Else Checks If the method is is Both and platform is Affy2
    ## Else Checks If the method is is BothIntersect and platform is Affy2
    ## Else Checks If the method is is BothIntersect and platform is Affy2
    ## Else prints the error message that Method/platform is invalid
    if (identical(method, "Pearson") & identical(Platform, "Affy1")) {
        finaldat1 <- Affy1_Pearson_Final[which(tolower
            (Affy1_Pearson_Final$miRNA) %in% tolower(miR)), ]
        ### Storing data in data.frame
        if (nrow(finaldat1) == 0) {
            print("Records of the miRNA does not exist")
        } else {
            finaldat1 <- cbind(finaldat1, method = rep("Pearson", nrow(finaldat1)))
            names(finaldat1) <- c("miRNA", "Target_GeneSymbol", "Targets_FBID", 
                "Targets_CGID", "Score", "GeneFunction", "Experiments", 
                "TargetDatabases", "Method")
        }
        ### If output is selected as Text, write in .csv file Else print to the
        ### console
        if (identical(Text, TRUE)) {
            ### If miRNA length >1 names concatenated with & else use the miR 
            ###name
            if (length(miR) > 1) {
                miRNAs <- paste(miR, collapse = "&")
            } else {
                miRNAs = miR
            }
            filename = paste("Targets_for_miRNAs_", miRNAs, "_", Platform, 
                "_", method, ".csv", sep = "")
            ### Check if the file name exists
            if (!(file.exists(file.path(outpath, filename)))) {
                write.csv(finaldat1, file = file.path(outpath, filename))
            } else {
                stop("File Already Exists!!")
            }
        } else {
            return(finaldat1)
        }
    } else if (identical(method, "Pearson") & identical(Platform, "Affy2")) {
        finaldat1 <- Affy2_Pearson_Final[which(tolower(Affy2_Pearson_Final$miRNA)
                %in% tolower(miR)), ]
        ### Storing data in data.frame
        if (nrow(finaldat1) == 0) {
            message("Records of the miRNA does not exist")
        } else {
            finaldat1 <- cbind(finaldat1, method = rep("Pearson", 
                    nrow(finaldat1)))
            names(finaldat1) <- c("miRNA", "Target_GeneSymbol", "Targets_FBID", 
                "Targets_CGID", "Score", "GeneFunction", "Experiments", 
                "TargetDatabases", "Method")
        }
        ### If output is selected as Text, write in .csv file Else print to the
        ### console
        if (identical(Text, TRUE)) {
            ### If miRNA length >1 names concatenated with & else use the miR 
            ### name
            if (length(miR) > 1) {
                miRNAs <- paste(miR, collapse = "&")
            } else {
                miRNAs = miR
            }
            filename = paste("Targets_for_miRNAs_", miRNAs, "_", Platform, 
                "_", method, ".csv", sep = "")
            ### Check if the file name exists
            if (!(file.exists(file.path(outpath, filename)))) {
                write.csv(finaldat1, file = file.path(outpath, filename))
            } else {
                stop("File Already Exists!!")
            }
        } else {
            return(finaldat1)
        }
    } else if (identical(method, "Distance") & identical(Platform, "Affy1")) {
        finaldat1 <- Affy1_Distance_Final[which(tolower
                    (Affy1_Distance_Final$miRNA) %in% tolower(miR)), ]
        ### Storing data in data.frame
        if (nrow(finaldat1) == 0) {
            message("Records of the miRNA does not exist")
        } else {
            finaldat1 <- cbind(finaldat1, method = rep("Distance", 
                        nrow(finaldat1)))
            names(finaldat1) <- c("miRNA", "Target_GeneSymbol", "Targets_FBID", 
                "Targets_CGID", "Score", "GeneFunction", "Experiments", 
                "TargetDatabases", "Method")
        }
        ### If output is selected as Text, write in .csv file Else print to the
        ### console
        if (identical(Text, TRUE)) {
            ### If miRNA length >1 names concatenated with & else use the miR 
            ### name
            if (length(miR) > 1) {
                miRNAs <- paste(miR, collapse = "&")
            } else {
                miRNAs = miR
            }
            filename = paste("Targets_for_miRNAs_", miRNAs, "_", Platform, 
                "_", method, ".csv", sep = "")
            ### Check if the file name exists
            if (!(file.exists(file.path(outpath, filename)))) {
                write.csv(finaldat1, file = file.path(outpath, filename))
            } else {
                stop("File Already Exists!!")
            }
        } else {
            return(finaldat1)
        }
    } else if (identical(method, "Distance") & identical(Platform, "Affy2")) {
        finaldat1 <- Affy2_Distance_Final[which(tolower
                    (Affy2_Distance_Final$miRNA) %in% tolower(miR)), ]
        ### Storing data in data.frame
        if (nrow(finaldat1) == 0) {
            message("Records of the miRNA does not exist")
        } else {
            finaldat1 <- cbind(finaldat1, method = rep("Distance", 
                    nrow(finaldat1)))
            names(finaldat1) <- c("miRNA", "Target_GeneSymbol", "Targets_FBID", 
                "Targets_CGID", "Score", "GeneFunction", "Experiments", 
                "TargetDatabases", "Method")
        }
        ### If output is selected as Text, write in .csv file Else print to the
        ### console
        if (identical(Text, TRUE)) {
            ### If miRNA length >1 names concatenated with & else use the miR 
            ### name
            if (length(miR) > 1) {
                miRNAs <- paste(miR, collapse = "&")
            } else {
                miRNAs = miR
            }
            filename = paste("Targets_for_miRNAs_", miRNAs, "_", Platform, 
                "_", method, ".csv", sep = "")
            ### Check if the file name exists
            if (!(file.exists(file.path(outpath, filename)))) {
                write.csv(finaldat1, file = file.path(outpath, filename))
            } else {
                stop("File Already Exists!!")
            }
        } else {
            return(finaldat1)
        }
    } else if (identical(method, "Both") & identical(Platform, "Affy1")) {
        ### Extracting from Pearson and Distance data Individually, then
        ### concatenating the by row.
        datD <- Affy1_Distance_Final[which(tolower(Affy1_Distance_Final$miRNA)
            %in% tolower(miR)), ]
        if (nrow(datD) == 0) {
            message("Records of the miRNA does not exist")
        } else {
            datD <- cbind(datD, method = rep("Distance", nrow(datD)))
        }
        datP <- Affy1_Pearson_Final[which(tolower(Affy1_Pearson_Final$miRNA)
                %in% tolower(miR)), ]
        if (nrow(datP) == 0) {
            message("Records of the miRNA does not exist")
        } else {
            datP <- cbind(datP, method = rep("Pearson", nrow(datP)))
        }
        
        ### Storing data in data.frame
        finaldat1 <- rbind(datP, datD)
        names(finaldat1) <- c("miRNA", "Target_GeneSymbol", "Targets_FBID", 
            "Targets_CGID", "Score", "GeneFunction", "Experiments", 
            "TargetDatabases", "Method")
        ### If output is selected as Text, write in .csv file Else print to the
        ### console
        if (identical(Text, TRUE)) {
            ### If miRNA length >1 names concatenated with & else use the miR
            ### name
            if (length(miR) > 1) {
                miRNAs <- paste(miR, collapse = "&")
            } else {
                miRNAs = miR
            }
            filename = paste("Targets_for_miRNAs_", miRNAs, "_", Platform, 
                "_", method, ".csv", sep = "")
            ### Check if the file name exists
            if (!(file.exists(file.path(outpath, filename)))) {
                write.csv(finaldat1, file = file.path(outpath, filename))
            } else {
                stop("File Already Exists!!")
            }
        } else {
            return(finaldat1)
        }
    } else if (identical(method, "Both") & identical(Platform, "Affy2")) {
        ### Extracting from Pearson and Distance data Individually, then
        ### concatenating the by row.
        
        datD <- Affy2_Distance_Final[which(tolower(Affy2_Distance_Final$miRNA)
        %in% tolower(miR)), ]
        if (nrow(datD) == 0) {
            message("Records of the miRNA does not exist")
        } else {
            datD <- cbind(datD, method = rep("Distance", nrow(datD)))
        }
        datP <- Affy2_Pearson_Final[which(tolower(Affy2_Pearson_Final$miRNA)
            %in% tolower(miR)), ]
        if (nrow(datD) == 0) {
            message("Records of the miRNA does not exist")
        } else {
            datP <- cbind(datP, method = rep("Pearson", nrow(datP)))
        }
        ### Storing data in data.frame
        finaldat1 <- rbind(datP, datD)
        names(finaldat1) <- c("miRNA", "Target_GeneSymbol", "Targets_FBID", 
            "Targets_CGID", "Score", "GeneFunction", "Experiments", 
            "TargetDatabases", "Method")
        ### If output is selected as Text, write in .csv file Else print to the
        ### console
        if (identical(Text, TRUE)) {
            ### If miRNA length >1 names concatenated with & else use the miR 
            ### name
            if (length(miR) > 1) {
                miRNAs <- paste(miR, collapse = "&")
            } else {
                miRNAs = miR
            }
            filename = paste("Targets_for_miRNAs_", miRNAs, "_", Platform, 
                "_", method, ".csv", sep = "")
            ### Check if the file name exists
            if (!(file.exists(file.path(outpath, filename)))) {
                write.csv(finaldat1, file = file.path(outpath, filename))
            } else {
                stop("File Already Exists!!")
            }
        } else {
            return(finaldat1)
        }
    } else if (identical(method, "BothIntersect") & identical(Platform, 
                "Affy1")) {
        ### Extracting from Pearson and Distance data Individually, and then
        ### finding intersection between the miRNAs and extracting data for the
        ### intersection miRNAs appropriately. Length miRNA>1
        finaldat <- data.frame()
        if (length(miR) > 1) {
            for (ii in seq_along(miR)) {
                
                datD <- Affy1_Distance_Final[which(tolower
                    (Affy1_Distance_Final$miRNA) %in% tolower(miR[ii])), ]
                datP <- Affy1_Pearson_Final[which(tolower
                    (Affy1_Pearson_Final$miRNA) %in% tolower(miR[ii])), ]
                if (nrow(datD) == 0 | nrow(datP) == 0) {
                  message("Records of the miRNA does not exist")
                } else {
                  ### Intersection of Distance and Pearson.
                  int <- intersect(as.character(datP$FBGN), 
                    as.character(datD$FBGN))
                  ### Extracting from individual datasets
                  
                  dat_P <- datP[which(as.character(datP$FBGN)
                        %in% as.character(int)),]
                  dat_D <- datD[which(as.character(datD$FBGN) 
                        %in% as.character(int)),]
                }
                ### Storing data for individual miRNAs
                finaldat1 <- cbind(dat_P[, 1:5], DistanceScore = dat_D[,5], 
                        Genefunc = dat_P[, 6], Pexp = dat_P[, 7], 
                        Dexp = dat_D[,7], TargetDB = dat_P[, 8])
                finaldat <- rbind(finaldat, finaldat1)
            }
            ### Storing data for teh query miRNAs in data.frame
            finaldat <- cbind(finaldat, method = rep("PearsonDistance", 
                nrow(finaldat)))
            names(finaldat) <- c("miRNA", "Target_GeneSymbol", "Targets_FBID", 
                "Targets_CGID", "PearsonScore", "DistanceScore", 
                "GeneFunction", "PearsonExperiments", "DistanceExperiments",
                "TargetDatabases", "Method")
        } else {
            datD <- Affy1_Distance_Final[which(tolower
                    (Affy1_Distance_Final$miRNA) %in% tolower(miR)), ]
            datP <- Affy1_Pearson_Final[which(tolower
                (Affy1_Pearson_Final$miRNA) %in% tolower(miR)), ]
            ### Intersection of Distance and Pearson.
            if (nrow(datD) == 0 | nrow(datP) == 0) {
                message("Records of the miRNA does not exist")
            } else {
                int <- intersect(as.character(datP$FBGN), 
                    as.character(datD$FBGN))
                dat_P <- datP[which(as.character(datP$FBGN)
                %in% as.character(int)),]
                dat_D <- datD[which(as.character(datD$FBGN)
                %in% as.character(int)),]
            }
            ### Extracting from individual datasets
            finaldat1 <- cbind(dat_P[, 1:5], DistanceScore = dat_D[, 5], 
                Genefunc = dat_P[, 6], Pexp = dat_P[, 7], Dexp = dat_D[,7],
                TargetDB = dat_P[, 8])
            ### Storing data
            finaldat <- cbind(finaldat1, method = rep("PearsonDistance", 
                nrow(finaldat1)))
            names(finaldat) <- c("miRNA", "Target_GeneSymbol", "Targets_FBID", 
                "Targets_CGID", "PearsonScore", "DistanceScore",  
                "GeneFunction", "PearsonExperiments", "DistanceExperiments",
                "TargetDatabases", "Method")
        }
        ### If output is selected as Text, write in .csv file Else print to the
        ### console
        if (identical(Text, TRUE)) {
            ### If miRNA length >1 names concatenated with & else use the miR 
            ### name
            if (length(miR) > 1) {
                miRNAs <- paste(miR, collapse = "&")
            } else {
                miRNAs = miR
            }
            filename = paste("Targets_for_miRNAs_", miRNAs, "_", Platform, 
                "_", method, ".csv", sep = "")
            ### Check if the file name exists
            if (!(file.exists(file.path(outpath, filename)))) {
                write.csv(finaldat, file = file.path(outpath, filename))
            } else {
                stop("File Already Exists!!")
            }
        } else {
            return(finaldat)
        }
    } else if (identical(method, "BothIntersect") & 
            identical(Platform, "Affy2")) {
        ### Extracting from Pearson and Distance data Individually, and then
        ### finding intersection between the miRNAs and extracting data for the
        ### intersection miRNAs appropriately. Length miRNA>1
        finaldat <- data.frame()
        if (length(miR) > 1) {
            for (ii in seq_along(miR)) {
                datD <- Affy2_Distance_Final[which
                    (tolower(Affy2_Distance_Final$miRNA) 
                    %in% tolower(miR[ii])), ]
                datP <- Affy2_Pearson_Final[which(
                    tolower(Affy2_Pearson_Final$miRNA)
                    %in% tolower(miR[ii])), ]
                if (nrow(datD) == 0 | nrow(datP) == 0) {
                    message("Records of the miRNA does not exist")
                } else {
                    ### Intersection of Distance and Pearson.
                    int <- intersect(as.character(datP$FBGN),
                        as.character(datD$FBGN))
                    ### Extracting from individual datasets
                    dat_P <- datP[which(as.character(datP$FBGN)
                        %in% as.character(int)),]
                    dat_D <- datD[which(as.character(datD$FBGN)
                    %in% as.character(int)),]
                }
                ### Storing data for individual miRNAs
                finaldat1 <- cbind(dat_P[, 1:5], dat_D[, 5], dat_P[, 6], 
                    dat_P[, 7], dat_D[, 7], dat_P[, 8])
                finaldat <- rbind(finaldat, finaldat1)
            }
            ### Storing data for teh query miRNAs in data.frame
            finaldat <- cbind(finaldat, method = rep("PearsonDistance", 
                nrow(finaldat)))
            names(finaldat) <- c("miRNA", "Target_GeneSymbol", "Targets_FBID", 
                "Targets_CGID", "PearsonScore", "DistanceScore", 
                "GeneFunction", "PearsonExperiments", "DistanceExperiments",
                "TargetDatabases", "Method")
        } else {
            datD <- Affy2_Distance_Final[which(tolower
                    (Affy2_Distance_Final$miRNA) %in% tolower(miR)), ]
            datP <- Affy2_Pearson_Final[which(tolower
                (Affy2_Pearson_Final$miRNA) %in% tolower(miR)), ]
            if (nrow(datD) == 0 | nrow(datP) == 0) {
                message("Records of the miRNA does not exist")
            } else {
                ### Intersection of Distance and Pearson.
                int <- intersect(as.character(datP$FBGN), 
                    as.character(datD$FBGN))
                ### Extracting from individual datasets
                dat_P <- datP[which(as.character(datP$FBGN)
                    %in% as.character(int)),]
                dat_D <- datD[which(as.character(datD$FBGN) 
                    %in% as.character(int)),]
            }
            finaldat1 <- cbind(dat_P[, 1:5], dat_D[, 5], dat_P[, 6], dat_P[,7],
                        dat_D[, 7], dat_P[, 8])
            ### Storing data in data.frame
            finaldat <- cbind(finaldat1, method = rep("PearsonDistance", 
                nrow(finaldat1)))
            names(finaldat) <- c("miRNA", "Target_GeneSymbol", "Targets_FBID", 
                "Targets_CGID", "PearsonScore", "DistanceScore", "GeneFunction", 
                "PearsonExperiments", "DistanceExperiments", "TargetDatabases", 
                "Method")
        }
        ### If output is selected as Text, write in .csv file Else print to the
        ### console
        if (identical(Text, TRUE)) {
            ### If miRNA length >1 names concatenated with & else use the miR
            ### name
            if (length(miR) > 1) {
                miRNAs <- paste(miR, collapse = "&")
            } else {
                miRNAs = miR
            }
            filename = paste("Targets_for_miRNAs_", miRNAs, "_", Platform, 
                "_", method, ".csv", sep = "")
            ### Check if the file name exists
            if (!(file.exists(file.path(outpath, filename)))) {
                write.csv(finaldat, file = file.path(outpath, filename))
            } else {
                stop("File Already Exists!!")
            }
        } else {
            return(finaldat)
        }
    } else {
        stop("Method and/or Platform does not exist")
    }
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/extract_miRNA_HostGene.r
\name{extract_intragenic_miR}
\alias{extract_intragenic_miR}
\title{Extract Intragenic miRNA for a given Host gene.}
\usage{
extract_intragenic_miR(gene)
}
\arguments{
\item{gene}{character. Gene Symbol.}
}
\value{
miRf, a character string or vector containing
        Intragenic miRNA for the Host Gene.
}
\description{
Extract Intragenic miRNA for a given Host gene.
}
\examples{
gene="Gmap"
extract_intragenic_miR(gene)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/extract_miRNA_HostGene.r
\name{extract_HostGene}
\alias{extract_HostGene}
\title{Extract Host Gene for a given Intragenic miRNA.}
\usage{
extract_HostGene(miRNA)
}
\arguments{
\item{miRNA}{A String containing the miRNA name.}
}
\value{
genf, a character string or vector containing
        Host gene for the Intragenic miRNA.
}
\description{
Extract Host Gene for a given Intragenic miRNA.
}
\examples{
miRNA="dme-miR-12"
extract_HostGene(miRNA)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Gene_Visualisation.r
\name{Gene_Visualisation}
\alias{Gene_Visualisation}
\title{Visualises the targetGene:miRNA network using Cytoscape and igraph .}
\usage{
Gene_Visualisation(
  mRNA,
  mRNA_type = c("GeneSymbol", "FBGN", "CGID"),
  method = c("Pearson", "Distance", "Both"),
  platform = c("Affy1", "Affy2"),
  visualisation = c("igraph", "Cytoscape", "text", "console"),
  path = tempdir(),
  layout = c("kamadakawai", "reingold.tilford", "fruchterman.reingold", "interactive")
)
}
\arguments{
\item{mRNA}{character. gene Identifier.}

\item{mRNA_type}{character. mRNA id type.
The choices are 'GeneSymbol','FBID' and 'CGID'.}

\item{method}{character. Statistical Methods. Choices are
'Pearson','Distance','Both'}

\item{platform}{character. Affymetrix Platforms. Choices are
'Affy1','Affy2'.}

\item{visualisation}{character.Visualisation type.
Choices are 'igraph','Cytoscape','text'and "console"}

\item{path}{character. Path where data.frame is saved when visualisation
is text. Default is tempdir().}

\item{layout}{character. Network choices. Choices are
'kamadakawai','reingold.tilford','fruchterman.reingold' 
  and 'interactive'.}
}
\value{
Depending upon the ouput choice network image or dataframe 
        containg miRNAs that target the query gene are ouput.
}
\description{
Visualises the targetGene:miRNA network using Cytoscape and igraph .
}
\examples{
mRNA='Syb'
Gene_Visualisation(mRNA,mRNA_type=c('GeneSymbol'),method=c('Pearson'),
                  platform=c('Affy1'), visualisation = "console")
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.r
\docType{data}
\name{miRNA_summary_DB}
\alias{miRNA_summary_DB}
\title{Contains the summary for the intragenic miRNA.}
\format{
A data frame with 257 rows and 6 variables:
\describe{
  \item{miRNA}{miRNA name, miRNA symbol}
  \item{Intragenic}{Responsee, in boolean}
  \item{Intergenic}{Responsee, in boolean}
  \item{Gene}{miRNA name, miRNA symbol}
  \item{Type.of.HostGene.mRNA.lncRNA.}{Type of Hostgene}
  \item{Notes}{Comments about the miRNA}
}
}
\usage{
miRNA_summary_DB
}
\description{
A dataset containing the summary for the intragenic miRNA.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/IntraMirExploreR.r
\docType{package}
\name{IntramiRExploreR}
\alias{IntramiRExploreR}
\title{IntramiRExploreR:Prediction of targets for Intragenic 
miRNA in Drosophila.}
\description{
Prediction of targets for Drosophila Intragenic microRNAs
and Integrated approach using Gene Ontology and Networking tools.
}
\examples{
\dontrun{
gene='Gmap'
extract_intragenic_miR(gene)
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/genes_Stat.r
\name{genes_Stat}
\alias{genes_Stat}
\title{Extracting miRNAs that target a query gene.}
\usage{
genes_Stat(
  gene,
  geneIDType = c("GeneSymbol", "FBGN", "CGID"),
  method = c("Pearson", "Distance", "Both", "BothIntersect"),
  Platform = c("Affy1", "Affy2"),
  Text = FALSE,
  outpath = tempdir()
)
}
\arguments{
\item{gene}{character. gene Identifier.}

\item{geneIDType}{character. GeneIDtype choices are 'GeneSymbol', 
'FBGN', 'CGID'}

\item{method}{character. Choices are 'Pearson','Distance','Both' and
'BothIntersected'}

\item{Platform}{character. Choices are
'Affy1','Affy2'.}

\item{Text}{logical . To choose between storing the data as text file.
Default is FALSE.}

\item{outpath}{character. The path where the data is stored if TEXT=TRUE.
Default is}
}
\value{
Outputs the miRNA information, Target Prediction Score, miRNA 
        miRNA function and Target Database that predicts the interaction in
        a dataframe.
        Depending upon the ouput choice data is stored in the
        path specified. Default option prints output to the console.
}
\description{
Extracting miRNAs that target a query gene.
}
\examples{
gene="Syb"
genes_Stat(gene,geneIDType="GeneSymbol",method=c("Pearson"),
           Platform=c("Affy1"),Text=FALSE)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GetGOS_ALL.r
\name{GetGOS_ALL}
\alias{GetGOS_ALL}
\title{Gene ontology for Target Genes.}
\usage{
GetGOS_ALL(
  gene,
  GO = c("topGO"),
  term = c("GOTERM_BP_ALL", "GOTERM_MF_ALL", "GOTERM_CC_ALL"),
  geneIdType = "ALIAS",
  path = tempdir(),
  ontology = c("GO_BP", "GO_MF", "GO_CC"),
  filename
)
}
\arguments{
\item{gene}{List  A String or vector containing the Gene names.}

\item{GO}{A String depicting the chosen GO tool. Choice is "topGO"}

\item{term}{A String depicting the chosen term. Choices are
"GOTERM_BP_ALL","GOTERM_MF_ALL", "GOTERM_CC_ALL".}

\item{geneIdType}{Type of gene Id given as input. Default "ALIAS"}

\item{path}{String. The path where the data is stored if TEXT=TRUE.}

\item{ontology}{Ontology selection for topGO. Choices are
"GO_BP","GO_MF","GO_CC".}

\item{filename}{Name of the file to store Gene Ontology.}
}
\value{
Depending upon the ouput choice data is stored in the path 
        specified. Default option prints output to the console.
}
\description{
Gene ontology for Target Genes.
}
\examples{
\dontrun{
miR="dme-miR-12"
a<-Visualisation(miR,mRNA_type=c("GeneSymbol"),method=c("Both"),
   platform=c("Affy1"),thresh=100)
genes<-a$Target_GeneSymbol
GetGOS_ALL(genes,GO=c("topGO"),term=c("GO_BP"),path=tempdir(),
     filename="test")
 }
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/miRTargets_Stat.r
\name{miRTargets_Stat}
\alias{miRTargets_Stat}
\title{Extracting miRNAs that target a query gene.}
\usage{
miRTargets_Stat(
  miR,
  method = c("Pearson", "Distance", "Both", "BothIntersect"),
  Platform = c("Affy1", "Affy2"),
  outpath = tempdir(),
  Text = FALSE
)
}
\arguments{
\item{miR}{character. miRNA symbol.}

\item{method}{character. Choices are "Pearson", "Distance","Both" 
and "BothIntersected"}

\item{Platform}{character. Choices are "Affy1","Affy2".}

\item{outpath}{character. The path where the data is stored if TEXT=TRUE.
Default is tempdir().}

\item{Text}{logical . To choose between storing the data as text file.
Default is FALSE.}
}
\value{
Outputs the target information, Target Prediction Score, miRNA 
        target function and Target Database that predicts the interaction in
        a dataframe.
        Depending upon the ouput choice data is stored in the
        path specified. Default option prints output to the console.
}
\description{
Extracting miRNAs that target a query gene.
}
\examples{
miRNA="dme-miR-12"
miRTargets_Stat (miRNA,method=c ("Pearson"),Platform=c ("Affy1"),Text=FALSE)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Visualisation.r
\name{Visualisation}
\alias{Visualisation}
\title{Visualises the targetGene:miRNA network using Cytoscape and igraph .}
\usage{
Visualisation(
  miRNA,
  mRNA_type = c("GeneSymbol", "FBID", "CGID"),
  method = c("Pearson", "Distance", "Both"),
  platform = c("Affy1", "Affy2"),
  thresh = 50,
  visualisation = c("igraph", "Cytoscape", "Text", "console"),
  path = tempdir(),
  layout = c("kamadakawai", "reingold.tilford", "fruchterman.reingold", "interactive")
)
}
\arguments{
\item{miRNA}{character. miRNA Identifier.}

\item{mRNA_type}{character. mRNA id type.
The choices are 'GeneSymbol','FBID' and 'CGID'.}

\item{method}{character. Statistical Methods. Choices are
'Pearson','Distance','Both'}

\item{platform}{character. Affymetrix Platforms. Choices are
'Affy1','Affy2'.}

\item{thresh}{integar. Threshold depicting number of rows to show.}

\item{visualisation}{character.Visualisation type.
Choices are 'igraph','Cytoscape','text' and 'console'.}

\item{path}{character. Path where data.frame is saved when visualisation
is text. Default is tempdir().}

\item{layout}{character. Network choices. Choices are
'kamadakawai','reingold.tilford','fruchterman.reingold' 
and 'interactive'.}
}
\value{
Depending upon the ouput choice network image or dataframe 
        containg miRNAs that target the query gene are ouput.
}
\description{
Visualises the targetGene:miRNA network using Cytoscape and igraph .
}
\examples{
miRNA='dme-miR-12'
Visualisation(miRNA,mRNA_type=c('GeneSymbol'),method=c('Pearson'),
platform=c('Affy1'),visualisation=c('igraph'),layout=c('kamadakawai'),
           path=tempdir())
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.r
\docType{data}
\name{Affy1_Pearson_Final}
\alias{Affy1_Pearson_Final}
\title{Targets for the microRNA analyzed from Affy1 plaform using Pearson.}
\format{
A data frame with 41845 rows and 8 variables:
\describe{
  \item{miRNA}{miRNA name, miRNA symbol}
  \item{GeneSymbol}{Gene name, in Gene Symbol}
  \item{FBGN}{Gene name, in FlybaseID}
  \item{CGID}{Gene name, in CGID}
  \item{Score}{Computed Score, in float}
  \item{GeneFunction}{Gene Functions, from Flybase}
  \item{experiments}{Experiments, from ArrayExpress}
  \item{TargetDatabases}{Target Database Name, from TargetDatabases}
}
}
\usage{
Affy1_Pearson_Final
}
\description{
A precomputed dataset containing the targets, scores and other 
attributes of 83 intragenic microRNAs using Pearson Correlation 
for plaform Affymetrix 1.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.r
\docType{data}
\name{miRNA_ID_to_Function}
\alias{miRNA_ID_to_Function}
\title{Contains the miRNA function information from Flybase database.}
\format{
A data frame with 66 rows and 4 variables:
\describe{
  \item{miRNA}{miRNA name, miRNA symbol}
  \item{FBGN}{target gene name, gene symbol}
  \item{miRNAFunction}{miRNA function, from Flybase}
}
}
\source{
\url{http://flybase.org/}
}
\usage{
miRNA_ID_to_Function
}
\description{
A dataset containing the function for the intragenic miRNA.
}
\keyword{datasets}
